@@ -2,14 +2,10 @@ OC.L10N.register(
     "activity",
     {
     "Activity" : "Aktivita",
-    "Personal activity feed for %s" : "Přehled aktivit uživatele %s",
-    "Your feed URL is invalid" : "URL adresa kanálu není platná",
-    "Your settings have been updated." : "Vaše nastavení bylo aktualizováno.",
-    "Mail" : "Pošta",
-    "Stream" : "Proud",
     "Activities" : "Aktivity",
     "Error loading activities" : "Chyba načtení aktivit",
     "No activities" : "Žádné aktivity",
+    "Load more activities" : "Načíst více aktivit",
     ", " : ", ",
     "{parameterList} and {lastParameter}" : "{parameterList} a {lastParameter}",
     "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} a {linkStart}%n další{linkEnd}","{parameterList} a {linkStart}%n další{linkEnd}","{parameterList} a {linkStart}%n dalších{linkEnd}"],
@@ -18,6 +14,11 @@ OC.L10N.register(
     "There are no events for this filter" : "Pro tato kritéria nejsou žádné události",
     "Today" : "Dnes",
     "Yesterday" : "Včera",
+    "Personal activity feed for %s" : "Přehled aktivit uživatele %s",
+    "Your feed URL is invalid" : "URL adresa kanálu není platná",
+    "Your settings have been updated." : "Vaše nastavení bylo aktualizováno.",
+    "Mail" : "Pošta",
+    "Stream" : "Proud",
     "\"remote user\"" : "\"vzdálený uživatel\"",
     "Activity notification" : "Upozornění na aktivity",
     "All Activities" : "Všechny aktivity",
@@ -25,10 +26,10 @@ OC.L10N.register(
     "Activities by others" : "Aktivity ostatních",
     "%s and %s" : "%s a %s",
     "Hello %s," : "Vítejte %s,",
-    "You are receiving this email because the following things happened at %s" : "Dostali jste tento email, protože došlo k následujícím změnám na %s",
+    "You are receiving this email because the following things happened at %s" : "Dostali jste tento email, protože došlo k následujícím událostem na %s",
     "* %1$s - %2$s" : "* %1$s - %2$s",
     "_* and %n more _::_* and %n more _" : ["* a %n další ","* a %n další ","* a %n dalších "],
-    "List your own actions in the stream" : "Zobrazovat vlastní činnosti v seznamu",
+    "List your own file actions in the stream" : "Seznam vašich souborových akcí v proudu",
     "Notify about your own actions via email" : "Posílat oznámení o vlastních činnostech emailem",
     "You need to set up your email address before you can receive notification emails." : "Pokud chcete dostávat upozornění emailem, musíte nejprve nastavit svou emailovou adresu.",
     "Send emails:" : "Posílat emaily:",
@@ -37,7 +38,7 @@ OC.L10N.register(
     "Weekly" : "Týdně",
     "Activity feed" : "Přehled aktivit",
     "Enable RSS feed" : "Povolit RSS kanál",
-    "No activity yet" : "Zatím bez aktivity",
+    "No activity yet" : "Zatím žádná aktivita",
     "No more events to load" : "Žádné další události k načtení",
     "Files" : "Soubory"
 },
