@@ -2,14 +2,10 @@ OC.L10N.register(
     "activity",
     {
     "Activity" : "Activiteit",
-    "Personal activity feed for %s" : "Persoonlijk activiteitenkanaal voor %s",
-    "Your feed URL is invalid" : "Uw feed URL is ongeldig",
-    "Your settings have been updated." : "Uw instellingen zijn bijgewerkt",
-    "Mail" : "E-mail",
-    "Stream" : "Doorlopend",
     "Activities" : "Activiteiten",
     "Error loading activities" : "Fout bij laden activiteiten",
     "No activities" : "Geen activiteiten",
+    "Load more activities" : "Laad meer activiteiten",
     ", " : ", ",
     "{parameterList} and {lastParameter}" : "{parameterList} en {lastParameter}",
     "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} en {linkStart}%n meer{linkEnd}","{parameterList} en {linkStart}%n meer{linkEnd}"],
@@ -18,6 +14,11 @@ OC.L10N.register(
     "There are no events for this filter" : "Er zijn geen afspraken voor dit filter",
     "Today" : "Vandaag",
     "Yesterday" : "Gisteren",
+    "Personal activity feed for %s" : "Persoonlijk activiteitenkanaal voor %s",
+    "Your feed URL is invalid" : "Uw feed URL is ongeldig",
+    "Your settings have been updated." : "Uw instellingen zijn bijgewerkt",
+    "Mail" : "E-mail",
+    "Stream" : "Doorlopend",
     "\"remote user\"" : "\"externe gebruiker\"",
     "Activity notification" : "Activiteitenmelding",
     "All Activities" : "Alle activiteiten",
@@ -25,10 +26,10 @@ OC.L10N.register(
     "Activities by others" : "Activiteiten van anderen",
     "%s and %s" : "%s en %s",
     "Hello %s," : "Hallo %s,",
-    "You are receiving this email because the following things happened at %s" : "U ontvangt deze e-mail omdat het volgende plaatsvond op %s.",
+    "You are receiving this email because the following things happened at %s" : "U ontvangt deze e-mail, omdat het volgende plaatsvond op %s.",
     "* %1$s - %2$s" : "* %1$s - %2$s",
     "_* and %n more _::_* and %n more _" : ["* en %n meer","* en %n meer"],
-    "List your own actions in the stream" : "Toon uw eigen acties in het overzicht",
+    "List your own file actions in the stream" : "Toon uw eigen bestandsacties in de stroom",
     "Notify about your own actions via email" : "Melding van uw eigen acties via e-mail",
     "You need to set up your email address before you can receive notification emails." : "U moet uw e-mailadres instellen voordat u meldingen kunt ontvangen.",
     "Send emails:" : "Verstuur e-mails:",
