@@ -2,14 +2,10 @@ OC.L10N.register(
     "activity",
     {
     "Activity" : "Atividade",
-    "Personal activity feed for %s" : "Alimentação de atividade pessoal para %s",
-    "Your feed URL is invalid" : "Sua URL de alimentação é inválida",
-    "Your settings have been updated." : "Suas configurações foram atualizadas.",
-    "Mail" : "EMail",
-    "Stream" : "Fluxo",
     "Activities" : "Atividades",
     "Error loading activities" : "Erro carregando atividades",
     "No activities" : "Nenhuma atividade",
+    "Load more activities" : "Carregar mais actividades",
     ", " : ",",
     "{parameterList} and {lastParameter}" : "{parameterList} e {lastParameter}",
     "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} e {linkStart}%n mais{linkEnd}","{parameterList} e {linkStart}%n mais{linkEnd}"],
@@ -18,6 +14,11 @@ OC.L10N.register(
     "There are no events for this filter" : "Não há eventos para este filtro",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
+    "Personal activity feed for %s" : "Alimentação de atividade pessoal para %s",
+    "Your feed URL is invalid" : "Sua URL de alimentação é inválida",
+    "Your settings have been updated." : "Suas configurações foram atualizadas.",
+    "Mail" : "EMail",
+    "Stream" : "Fluxo",
     "\"remote user\"" : "\"usuário remoto\"",
     "Activity notification" : "Notificação de atividade",
     "All Activities" : "Todas as Atividades",
@@ -28,7 +29,7 @@ OC.L10N.register(
     "You are receiving this email because the following things happened at %s" : "Você está recebendo este e-mail porque  ocorreu o seguinte em %s",
     "* %1$s - %2$s" : "* %1$s - %2$s",
     "_* and %n more _::_* and %n more _" : ["* e %n mais","* e %n mais "],
-    "List your own actions in the stream" : "Liste suas próprias ações no fluxo",
+    "List your own file actions in the stream" : "Lista de suas próprias ações de arquivo no fluxo",
     "Notify about your own actions via email" : "Notificar sobre suas próprias ações por e-mail",
     "You need to set up your email address before you can receive notification emails." : "Você precisa configurar o endereço de e-mail antes que você possa receber e-mails de notificação.",
     "Send emails:" : "Enviar e-mails:",
