@@ -1,22 +1,26 @@
 OC.L10N.register(
     "comments",
     {
-    "<strong>Comments</strong> for files" : "<strong>Komentáře</strong> souborů",
-    "%1$s commented" : "%1$s okomentován",
-    "%1$s commented on %2$s" : "%1$s okomentoval %2$s",
-    "Comments" : "Komentáře",
     "Type in a new comment..." : "Zadat nový komentář...",
     "Delete comment" : "Smazat komentář",
     "Post" : "Zveřejnit",
     "Cancel" : "Zrušit",
     "Edit comment" : "Upravit komentář",
     "[Deleted user]" : "[Smazaný uživatel]",
+    "Comments" : "Komentáře",
     "No other comments available" : "Nejsou dostupné žádné další komentáře",
     "More comments..." : "Více komentářů...",
     "Save" : "Uložit",
     "Allowed characters {count} of {max}" : "Povolených znaků {count} z {max}",
+    "Error occurred while retrieving comment with id {id}" : "Došlo k chybě při načítání komentáře s id {id}",
+    "Error occurred while updating comment with id {id}" : "Došlo k chybě při aktualizování komentáře s id {id}",
+    "Error occurred while posting comment" : "Došlo k chybě při zveřejňování komentáře",
     "{count} unread comments" : "{count} nepřečtených komentářů",
     "Comment" : "Komentář",
-    "<strong>Comments</strong> for files" : "<strong>Komentáře</strong> souborů"
+    "<strong>Comments</strong> for files <em>(always listed in stream)</em>" : "<strong>Komentáře</strong> pro soubory <em>(vždy uvedeny v proudu)</em>",
+    "You commented" : "Okomentoval(a) jsi",
+    "%1$s commented" : "%1$s okomentován",
+    "You commented on %2$s" : "Okomentoval(a) jsi %2$s",
+    "%1$s commented on %2$s" : "%1$s okomentoval %2$s"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
