@@ -21,27 +21,36 @@ OC.L10N.register(
     "Invalid directory." : "Ugyldig mappe.",
     "Files" : "Filer",
     "All files" : "Alle filer",
-    "Favorites" : "Foretrukne",
     "Home" : "Hjemme",
     "Close" : "Luk",
+    "Favorites" : "Foretrukne",
     "Upload cancelled." : "Upload afbrudt.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke upload {filename} da det er enten en mappe eller indholder 0 bytes.",
     "Total file size {size1} exceeds upload limit {size2}" : "Den totale filstørrelse {size1} er større end uploadgrænsen {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkeligt friplads. Du uplaoder {size1} men der er kun {size2} tilbage",
+    "Error uploading file \"{fileName}\": {message}" : "Fejl under upload af filen \"{fileName}\": {message}",
     "Could not get result from server." : "Kunne ikke hente resultat fra server.",
+    "Uploading..." : "Uploader...",
+    "..." : "...",
+    "Any moment now..." : "Når som helst...",
+    "Soon..." : "Snart...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Fil upload kører. Hvis du forlader siden nu, vil uploadet blive annuleret.",
     "Actions" : "Handlinger",
     "Download" : "Download",
     "Rename" : "Omdøb",
     "Delete" : "Slet",
     "Disconnect storage" : "Frakobl lager",
-    "Unshare" : "Fjern deling",
+    "Unshare" : "Ophæv deling",
     "Details" : "Detaljer",
     "Select" : "Vælg",
     "Pending" : "Afventer",
     "Unable to determine date" : "Kan ikke fastslå datoen",
     "This operation is forbidden" : "Denne operation er forbudt",
     "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
+    "Could not move \"{file}\", target exists" : "Kunne ikke flytte \"{file}\" - der findes allerede en fil med dette navn",
+    "Could not move \"{file}\"" : "Kunne ikke flytte \"{file}\"",
+    "{newName} already exists" : "{newName} eksistere allerede",
+    "Error deleting file \"{fileName}\"." : "Fejl under sletning af filen \"{fileName}\"",
     "No entries in this folder match '{filter}'" : "Der er ingen poster i denne mappe, der matcher '{filter}'",
     "Name" : "Navn",
     "Size" : "Størrelse",
@@ -63,6 +72,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Gjort til foretrukken",
     "Favorite" : "Foretrukken",
+    "Local link" : "Lokalt link",
     "Folder" : "Mappe",
     "New folder" : "Ny Mappe",
     "{newname} already exists" : "{newname} eksistere allerede",
@@ -90,10 +100,10 @@ OC.L10N.register(
     "Maximum upload size" : "Maksimal upload-størrelse",
     "max. possible: " : "max. mulige: ",
     "Save" : "Gem",
+    "Missing permissions to edit from here." : "Rettighed mangler til at redigere på dette sted",
     "Settings" : "Indstillinger",
+    "Show hidden files" : "Vis skjulte filer",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Brug denne adresse for at <a href=\"%s\" target=\"_blank\">tilgå dine filer via WebDAV</a>",
-    "Cancel upload" : "Fortryd upload",
     "No files in here" : "Her er ingen filer",
     "Upload some content or sync with your devices!" : "Overfør indhold eller synkronisér med dine enheder!",
     "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
@@ -103,13 +113,6 @@ OC.L10N.register(
     "No favorites" : "Ingen foretrukne",
     "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her",
     "Text file" : "Tekstfil",
-    "New text file.txt" : "Ny tekst file.txt",
-    "Changed by %2$s" : "Ændret af %2$s",
-    "Deleted by %2$s" : "Slettet af %2$s",
-    "Restored by %2$s" : "Gendannet af %2$s",
-    "You changed %1$s" : "Du ændrede %1$s",
-    "You created %1$s" : "Du oprettede %1$s ",
-    "You deleted %1$s" : "Du slettede %1$s",
-    "You restored %1$s" : "Du gendannede %1$s"
+    "New text file.txt" : "Ny tekst file.txt"
 },
 "nplurals=2; plural=(n != 1);");
