@@ -21,15 +21,27 @@ OC.L10N.register(
     "Invalid directory." : "Invalid directory.",
     "Files" : "Files",
     "All files" : "All files",
-    "Favorites" : "Favourites",
+    "File could not be found" : "File could not be found",
     "Home" : "Home",
     "Close" : "Close",
+    "Favorites" : "Favourites",
     "Upload cancelled." : "Upload cancelled.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
     "Total file size {size1} exceeds upload limit {size2}" : "Total file size {size1} exceeds upload limit {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
     "Error uploading file \"{fileName}\": {message}" : "Error uploading file \"{fileName}\": {message}",
     "Could not get result from server." : "Could not get result from server.",
+    "Uploading..." : "Uploading...",
+    "..." : "...",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} hour{plural_s} left",
+    "{hours}:{minutes}h" : "{hours}:{minutes}h",
+    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minute{plural_s} left",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
+    "{seconds} second{plural_s} left" : "{seconds} second{plural_s} left",
+    "{seconds}s" : "{seconds}s",
+    "Any moment now..." : "Any moment now...",
+    "Soon..." : "Soon...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "File upload is in progress. Leaving the page now will cancel the upload.",
     "Actions" : "Actions",
     "Download" : "Download",
@@ -75,6 +87,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Favourited",
     "Favorite" : "Favourite",
+    "Local link" : "Local link",
     "Folder" : "Folder",
     "New folder" : "New folder",
     "{newname} already exists" : "{newname} already exists",
@@ -105,9 +118,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "With PHP-FPM it might take 5 minutes for changes to be applied.",
     "Missing permissions to edit from here." : "Missing permissions to edit from here.",
     "Settings" : "Settings",
+    "Show hidden files" : "Show hidden files",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>",
-    "Cancel upload" : "Cancel upload",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>",
     "No files in here" : "No files in here",
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
     "No entries found in this folder" : "No entries found in this folder",
@@ -117,13 +130,6 @@ OC.L10N.register(
     "No favorites" : "No favourites",
     "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
     "Text file" : "Text file",
-    "New text file.txt" : "New text file.txt",
-    "Changed by %2$s" : "Changed by %2$s",
-    "Deleted by %2$s" : "Deleted by %2$s",
-    "Restored by %2$s" : "Restored by %2$s",
-    "You changed %1$s" : "You changed %1$s",
-    "You created %1$s" : "You created %1$s",
-    "You deleted %1$s" : "You deleted %1$s",
-    "You restored %1$s" : "You restored %1$s"
+    "New text file.txt" : "New text file.txt"
 },
 "nplurals=2; plural=(n != 1);");
