@@ -21,15 +21,27 @@ OC.L10N.register(
     "Invalid directory." : "無効なディレクトリです。",
     "Files" : "ファイル",
     "All files" : "すべてのファイル",
-    "Favorites" : "お気に入り",
+    "File could not be found" : "ファイルは見つかりませんでした。",
     "Home" : "ホーム",
     "Close" : "閉じる",
+    "Favorites" : "お気に入り",
     "Upload cancelled." : "アップロードはキャンセルされました。",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリもしくは0バイトのため {filename} をアップロードできません",
     "Total file size {size1} exceeds upload limit {size2}" : "合計ファイルサイズ {size1} はアップロード制限 {size2} を超過しています。",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
     "Error uploading file \"{fileName}\": {message}" : "ファイル\"{fileName}\"のアップロードエラー: {message}",
     "Could not get result from server." : "サーバーから結果を取得できませんでした。",
+    "Uploading..." : "アップロード中...",
+    "..." : "…",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "残り{hours}:{minutes}:{seconds} 時間",
+    "{hours}:{minutes}h" : "{hours}:{minutes} 時間",
+    "{minutes}:{seconds} minute{plural_s} left" : "残り{minutes}:{seconds} 分",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds} 分",
+    "{seconds} second{plural_s} left" : "残り{minutes}:{seconds} 秒",
+    "{seconds}s" : "{seconds} 秒",
+    "Any moment now..." : "もうすぐ…",
+    "Soon..." : "もうすぐ…",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "ファイル転送を実行中です。今このページから移動するとアップロードが中止されます。",
     "Actions" : "アクション",
     "Download" : "ダウンロード",
@@ -75,6 +87,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n バイト"],
     "Favorited" : "お気に入り済",
     "Favorite" : "お気に入り",
+    "Local link" : "ローカルリンク",
     "Folder" : "フォルダー",
     "New folder" : "新しいフォルダー",
     "{newname} already exists" : "{newname} はすでに存在します",
@@ -105,9 +118,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM の場合は値を変更後、反映されるのに5分程度かかります。",
     "Missing permissions to edit from here." : "ここから編集するための権限がありません。",
     "Settings" : "設定",
+    "Show hidden files" : "隠しファイルを表示",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\">WebDAV経由でのファイルアクセス</a>にはこのアドレスを利用してください",
-    "Cancel upload" : "アップロードをキャンセル",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">WebDAV 経由でファイルにアクセス</a> するにはこのアドレスを利用してください",
     "No files in here" : "ファイルがありません",
     "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
     "No entries found in this folder" : "このフォルダーにはエントリーがありません",
@@ -117,13 +130,6 @@ OC.L10N.register(
     "No favorites" : "お気に入りなし",
     "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
     "Text file" : "テキストファイル",
-    "New text file.txt" : "新規のテキストファイル作成",
-    "Changed by %2$s" : "%2$s により更新",
-    "Deleted by %2$s" : "%2$s により削除",
-    "Restored by %2$s" : "%2$s により復元",
-    "You changed %1$s" : "あなたは %1$s を変更しました",
-    "You created %1$s" : "あなたは %1$s を作成しました",
-    "You deleted %1$s" : "あなたは %1$s を削除しました",
-    "You restored %1$s" : "%1$s を復元しました"
+    "New text file.txt" : "新規のテキストファイル作成"
 },
 "nplurals=1; plural=0;");
