@@ -21,14 +21,18 @@ OC.L10N.register(
     "Invalid directory." : "올바르지 않은 디렉터리입니다.",
     "Files" : "파일",
     "All files" : "모든 파일",
-    "Favorites" : "즐겨찾기",
     "Home" : "가정",
     "Close" : "닫기",
+    "Favorites" : "즐겨찾기",
     "Upload cancelled." : "업로드가 취소되었습니다.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename}을(를) 업로드할 수 없습니다. 폴더이거나 0 바이트 파일입니다.",
     "Total file size {size1} exceeds upload limit {size2}" : "총 파일 크기 {size1}이(가) 업로드 제한 {size2}을(를) 초과함",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "빈 공간이 부족합니다. 업로드할 파일 크기는 {size1}이지만 현재 {size2}만큼 비었습니다",
+    "Error uploading file \"{fileName}\": {message}" : "\"{fileName}\"을(를) 업로드할 수 없음: {message}",
     "Could not get result from server." : "서버에서 결과를 가져올 수 없습니다.",
+    "Uploading..." : "업로드 중...",
+    "..." : "...",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} 시간 {plural_s} 남음",
     "File upload is in progress. Leaving the page now will cancel the upload." : "파일 업로드가 진행 중입니다. 이 페이지를 벗어나면 업로드가 취소됩니다.",
     "Actions" : "작업",
     "Download" : "다운로드",
@@ -42,6 +46,17 @@ OC.L10N.register(
     "Unable to determine date" : "날짜를 결정할 수 없음",
     "This operation is forbidden" : "이 작업이 금지됨",
     "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
+    "Could not move \"{file}\", target exists" : "\"{file}\"을(를) 이동할 수 없음, 대상이 존재함",
+    "Could not move \"{file}\"" : "\"{file}\"을(를) 이동할 수 없음",
+    "{newName} already exists" : "{newName}이(가) 이미 존재함",
+    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\"의 이름을 변경할 수 없음, 더 이상 존재하지 않음",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{dir}\" 폴더 내에 \"{targetName}\" 파일이 이미 있습니다. 다른 이름을 사용하십시오.",
+    "Could not rename \"{fileName}\"" : "\"{fileName}\"의 이름을 바꿀 수 없음",
+    "Could not create file \"{file}\"" : "\"{file}\"을(를) 만들 수 없음",
+    "Could not create file \"{file}\" because it already exists" : "파일이 이미 존재하므로 \"{file}\"을(를) 만들 수 없음",
+    "Could not create folder \"{dir}\"" : "폴더 \"{dir}\"을(를) 만들 수 없음",
+    "Could not create folder \"{dir}\" because it already exists" : "폴더가 이미 존재하므로 폴더 \"{dir}\"을(를) 만들 수 없음",
+    "Error deleting file \"{fileName}\"." : "파일 \"{fileName}\"을(를) 삭제할 수 없습니다.",
     "No entries in this folder match '{filter}'" : "이 폴더에 '{filter}'와(과) 일치하는 항목 없음",
     "Name" : "이름",
     "Size" : "크기",
@@ -90,10 +105,10 @@ OC.L10N.register(
     "Maximum upload size" : "최대 업로드 크기",
     "max. possible: " : "최대 가능:",
     "Save" : "저장",
+    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM을 사용 중이면 변경 사항이 적용되는 데 최대 5분 정도 걸릴 수 있습니다.",
+    "Missing permissions to edit from here." : "여기에서 편집할 권한이 없습니다.",
     "Settings" : "설정",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "WebDAV로 파일에 접근하려면 <a href=\"%s\" target=\"_blank\">이 주소를 사용하십시오</a>",
-    "Cancel upload" : "업로드 취소",
     "No files in here" : "여기에 파일 없음",
     "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
     "No entries found in this folder" : "이 폴더에 항목 없음",
@@ -103,13 +118,6 @@ OC.L10N.register(
     "No favorites" : "책갈피 없음",
     "Files and folders you mark as favorite will show up here" : "책갈피에 추가한 파일과 폴더가 여기에 나타납니다",
     "Text file" : "텍스트 파일",
-    "New text file.txt" : "새 텍스트 파일.txt",
-    "Changed by %2$s" : "%2$s 님이 변경함",
-    "Deleted by %2$s" : "%2$s 님이 삭제함",
-    "Restored by %2$s" : "%2$s 님이 복원함",
-    "You changed %1$s" : "내가 %1$s을(를) 변경함",
-    "You created %1$s" : "내가 %1$s을(를) 생성함",
-    "You deleted %1$s" : "내가 %1$s을(를) 삭제함",
-    "You restored %1$s" : "내가 %1$s을(를) 복원함"
+    "New text file.txt" : "새 텍스트 파일.txt"
 },
 "nplurals=1; plural=0;");
