@@ -21,14 +21,15 @@ OC.L10N.register(
     "Invalid directory." : "Nederīga direktorija.",
     "Files" : "Datnes",
     "All files" : "Visas datnes",
-    "Favorites" : "Iecienītie",
     "Home" : "Mājas",
     "Close" : "Aizvērt",
+    "Favorites" : "Iecienītie",
     "Upload cancelled." : "Augšupielāde ir atcelta.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturošs fails.",
     "Total file size {size1} exceeds upload limit {size2}" : "Kopējais faila izmērs {size1} pārsniedz augšupielādes ierobežojumu {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
     "Could not get result from server." : "Nevar saņemt rezultātus no servera",
+    "Uploading..." : "Augšupielādē...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Notiek augšupielāde. Pametot lapu tagad, tiks atcelta augšupielāde.",
     "Actions" : "Darbības",
     "Download" : "Lejupielādēt",
@@ -40,6 +41,8 @@ OC.L10N.register(
     "Select" : "Norādīt",
     "Pending" : "Gaida savu kārtu",
     "Unable to determine date" : "Neizdevās noteikt datumu",
+    "This operation is forbidden" : "Šī darbība ir aizliegta",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Šis direktorijs nav pieejams, lūdzu pārbaudiet žurnālus vai sazinieties ar administratoru",
     "No entries in this folder match '{filter}'" : "Šajā mapē nekas nav atrasts, meklējot pēc '{filter}'",
     "Name" : "Nosaukums",
     "Size" : "Izmērs",
@@ -81,8 +84,6 @@ OC.L10N.register(
     "Save" : "Saglabāt",
     "Settings" : "Iestatījumi",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Izmantojot šo adresi, <a href=\"%s\" target=\"_blank\">piekļūstiet saviem failiem, izmantojot WebDAV</a>",
-    "Cancel upload" : "Atcelt augšupielādi",
     "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
     "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
     "Select all" : "Atzīmēt visu",
