@@ -7,6 +7,19 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "Krok 1 zlyhal. Výnimka: %s",
     "Step 2 failed. Exception: %s" : "Krok 2 zlyhal. Výnimka: %s",
     "External storage" : "Externé úložisko",
+    "Personal" : "Osobné",
+    "System" : "Systém",
+    "Grant access" : "Povoliť prístup",
+    "Error configuring OAuth1" : "Chyba konfigurovania OAuth1",
+    "Error configuring OAuth2" : "Chyba konfigurovania OAuth2",
+    "Generate keys" : "Vytvoriť kľúče",
+    "Error generating key pair" : "Chyba pri vytváraní dvojice kľúčov",
+    "All users. Type to select user or group." : "Všetci používatelia. Začnite písať pre výber používateľa alebo skupinu.",
+    "(group)" : "(skupina)",
+    "Saved" : "Uložené",
+    "Username" : "Používateľské meno",
+    "Password" : "Heslo",
+    "Save" : "Uložiť",
     "Storage with id \"%i\" not found" : "Úložisko s ID \"%i\" sa nenašlo",
     "Invalid backend or authentication mechanism class" : "Neplatný backend, prípadne trieda mechanizmu autentifikácie",
     "Invalid mount point" : "Chybný prípojný bod",
@@ -16,25 +29,6 @@ OC.L10N.register(
     "Not permitted to use authentication mechanism \"%s\"" : "Nie je povolené použiť autentifikačný mechanizmus \"%s\"",
     "Unsatisfied backend parameters" : "Nedostatočné parametre backendu",
     "Unsatisfied authentication mechanism parameters" : "Nedostatočné parametre autentifikačného mechanizmu",
-    "Personal" : "Osobné",
-    "System" : "Systém",
-    "Grant access" : "Povoliť prístup",
-    "Access granted" : "Prístup povolený",
-    "Error configuring OAuth1" : "Chyba konfigurovania OAuth1",
-    "Error configuring OAuth2" : "Chyba konfigurovania OAuth2",
-    "Generate keys" : "Vytvoriť kľúče",
-    "Error generating key pair" : "Chyba pri vytváraní dvojice kľúčov",
-    "Enable encryption" : "Povoliť šifrovanie",
-    "Enable previews" : "Povoliť náhľady",
-    "Check for changes" : "Zisťovať zmeny",
-    "Never" : "Nikdy",
-    "Once every direct access" : "S každým priamym prístupom",
-    "All users. Type to select user or group." : "Všetci používatelia. Začnite písať pre výber používateľa alebo skupinu.",
-    "(group)" : "(skupina)",
-    "Saved" : "Uložené",
-    "Username" : "Používateľské meno",
-    "Password" : "Heslo",
-    "Save" : "Uložiť",
     "Access key" : "Prístupový kľúč",
     "Secret key" : "Tajný kľúč",
     "Builtin" : "Vstavaný",
@@ -91,6 +85,11 @@ OC.L10N.register(
     "Name" : "Názov",
     "Storage type" : "Typ úložiska",
     "Scope" : "Rozsah",
+    "Enable encryption" : "Povoliť šifrovanie",
+    "Enable previews" : "Povoliť náhľady",
+    "Check for changes" : "Zisťovať zmeny",
+    "Never" : "Nikdy",
+    "Once every direct access" : "S každým priamym prístupom",
     "External Storage" : "Externé úložisko",
     "Folder name" : "Názov priečinka",
     "Authentication" : "Autentifikácia",
@@ -99,7 +98,6 @@ OC.L10N.register(
     "Add storage" : "Pridať úložisko",
     "Advanced settings" : "Rozšírené nastavenia",
     "Delete" : "Zmazať",
-    "Allow users to mount the following external storage" : "Povoliť používateľom pripojiť tieto externé úložiská",
-    "SMB / CIFS" : "SMB / CIFS"
+    "Allow users to mount the following external storage" : "Povoliť používateľom pripojiť tieto externé úložiská"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
