@@ -1,8 +1,10 @@
 <?php
 /**
+ * @author Björn Schießle <bjoern@schiessle.org>
  * @author Joas Schilling <nickvergessen@owncloud.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <icewind@owncloud.com>
+ * @author Stefan Weil <sw@weilnetz.de>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
  * @copyright Copyright (c) 2016, ownCloud, Inc.
@@ -29,7 +31,10 @@ if (!isset($_GET['t'])) {
 	exit;
 }
 
-if (OCA\Files_Sharing\Helper::isOutgoingServer2serverShareEnabled() === false) {
+$federatedSharingApp = new \OCA\FederatedFileSharing\AppInfo\Application('federatedfilesharing');
+$federatedShareProvider = $federatedSharingApp->getFederatedShareProvider();
+
+if ($federatedShareProvider->isOutgoingServer2serverShareEnabled() === false) {
 	\OC_Response::setStatus(404); // 404 not found
 	exit;
 }
@@ -62,29 +67,37 @@ if (!$isWritable) {
 $rootInfo = \OC\Files\Filesystem::getFileInfo($path);
 $rootView = new \OC\Files\View('');
 
+$shareManager = \OC::$server->getShareManager();
+$share = $shareManager->getShareByToken($token);
+$sharePermissions= (int)$share->getPermissions();
+
 /**
  * @param \OCP\Files\FileInfo $dir
  * @param \OC\Files\View $view
  * @return array
  */
-function getChildInfo($dir, $view) {
+function getChildInfo($dir, $view, $sharePermissions) {
 	$children = $view->getDirectoryContent($dir->getPath());
 	$result = array();
 	foreach ($children as $child) {
-		$formated = \OCA\Files\Helper::formatFileInfo($child);
+		$formatted = \OCA\Files\Helper::formatFileInfo($child);
 		if ($child->getType() === 'dir') {
-			$formated['children'] = getChildInfo($child, $view);
+			$formatted['children'] = getChildInfo($child, $view, $sharePermissions);
 		}
-		$formated['mtime'] = $formated['mtime'] / 1000;
-		$result[] = $formated;
+		$formatted['mtime'] = $formatted['mtime'] / 1000;
+		$formatted['permissions'] = $sharePermissions & (int)$formatted['permissions'];
+		$result[] = $formatted;
 	}
 	return $result;
 }
 
 $result = \OCA\Files\Helper::formatFileInfo($rootInfo);
 $result['mtime'] = $result['mtime'] / 1000;
+$result['permissions'] = (int)$result['permissions'] & $sharePermissions;
+
+
 if ($rootInfo->getType() === 'dir') {
-	$result['children'] = getChildInfo($rootInfo, $rootView);
+	$result['children'] = getChildInfo($rootInfo, $rootView, $sharePermissions);
 }
 
 OCP\JSON::success(array('data' => $result));
