@@ -11,7 +11,6 @@ OC.L10N.register(
     "Shared with you" : "Gedeeld met u",
     "Shared with others" : "Gedeeld door u",
     "Shared by link" : "Gedeeld via een link",
-    "Federated sharing" : "Federated sharing",
     "Nothing shared with you yet" : "Nog niets met u gedeeld",
     "Files and folders others share with you will show up here" : "Bestanden en mappen die anderen met u delen, worden hier getoond",
     "Nothing shared yet" : "Nog niets gedeeld",
@@ -28,6 +27,25 @@ OC.L10N.register(
     "Invalid ownCloud url" : "Ongeldige ownCloud url",
     "Shared by" : "Gedeeld door",
     "Sharing" : "Delen",
+    "Share API is disabled" : "Delen API is uitgeschakeld",
+    "Wrong share ID, share doesn't exist" : "Onjuist deel-ID, de share bestaat niet",
+    "Could not delete share" : "Kon share niet verwijderen",
+    "Please specify a file or folder path" : "Geef een bestand of pad van een map op",
+    "Wrong path, file/folder doesn't exist" : "Onjuist pad, bestand/map bestaat niet",
+    "Please specify a valid user" : "Geef een geldige gebruiker op",
+    "Group sharing is disabled by the administrator" : "Delen voor groepen is uitgeschakeld door de beheerder",
+    "Please specify a valid group" : "Geef een geldige groep op",
+    "Public link sharing is disabled by the administrator" : "Delen van openbare links is uitgeschakeld door de beheerder",
+    "Public upload disabled by the administrator" : "Publieke upload uitgeschakeld door de systeembeheerder",
+    "Public upload is only possible for publicly shared folders" : "Publieke upload is alleen mogelijk voor publiek gedeelde mappen",
+    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, datumnotatie moet in de vorm YYYY-MM-DD",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "Delen van %s mislukte omdat de backend het delen van type %s niet ondersteunt",
+    "Unknown share type" : "Onbekend type share",
+    "Not a directory" : "Geen directory",
+    "Could not lock path" : "Kon pad niet blokkeren",
+    "Can't change permissions for public share links" : "Kan permissies voor openbare share links niet wijzigen",
+    "Wrong or no update parameter given" : "Verkeerde of geen update parameter gegeven",
+    "Cannot increase permissions" : "Kan de rechten niet verruimen",
     "A file or folder has been <strong>shared</strong>" : "Een bestand of map is <strong>gedeeld</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Een bestand of map werd gedeeld vanaf <strong>een andere server</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "Een openbaar gedeeld bestand of map werd <strong>gedownloaded</strong>",
@@ -71,11 +89,6 @@ OC.L10N.register(
     "Public link of %2$s expired" : "Openbare link van %2$s is verlopen",
     "Shared by %2$s" : "Gedeeld door %2$s",
     "Shares" : "Gedeeld",
-    "You received \"/%2$s\" as a remote share from %1$s" : "U ontving \"/%2$s\" als een externe share van %1$s",
-    "Accept" : "Accepteren",
-    "Decline" : "Afwijzen",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Deel met mij via mijn #ownCloud federated Cloud ID, zie %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Deel met mij via mijn #ownCloud federated Cloud ID",
     "This share is password-protected" : "Deze share is met een wachtwoord beveiligd",
     "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
     "Password" : "Wachtwoord",
@@ -91,16 +104,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Toevoegen aan uw ownCloud",
     "Download" : "Downloaden",
     "Download %s" : "Download %s",
-    "Direct link" : "Directe link",
-    "Federated Cloud Sharing" : "Federated Cloud Sharing",
-    "Open documentation" : "Open documentatie",
-    "Allow users on this server to send shares to other servers" : "Toestaan dat gebruikers op deze server shares sturen naar andere servers",
-    "Allow users on this server to receive shares from other servers" : "Toestaan dat gebruikers op deze server shares ontvangen van andere servers",
-    "Federated Cloud" : "Gefedereerde Cloud",
-    "Your Federated Cloud ID:" : "Uw Federated Cloud ID:",
-    "Share it:" : "Deel het:",
-    "Add to your website" : "Toevoegen aan uw website",
-    "Share with me via ownCloud" : "Deel met mij via ownCloud",
-    "HTML Code:" : "HTML Code:"
+    "Direct link" : "Directe link"
 },
 "nplurals=2; plural=(n != 1);");
