@@ -4,6 +4,8 @@ OC.L10N.register(
     "This file is too big to be opened. Please download the file instead." : "Diese Datei ist zu groß. Bitte lade die Datei stattdessen herunter.",
     "Cannot read the file." : "Datei kann nicht gelesen werden",
     "Invalid file path supplied." : "Ungültiger Dateipfad angegeben.",
+    "The file is locked." : "Die Datei ist gesperrt.",
+    "An internal server error occurred." : "Es ist ein interner Fehler aufgetreten.",
     "Cannot save file as it has been modified since opening" : "Die Datei konnte nicht gespeichert werden, weil sie seit dem Öffnen verändert worden ist",
     "Insufficient permissions" : "Nicht ausreichende Berechtigungen",
     "File path not supplied" : "Dateipfad nicht angegeben",
@@ -13,6 +15,8 @@ OC.L10N.register(
     "failed!" : "fehlgeschlagen!",
     "Saved" : "Gespeichert",
     "There was a problem saving your changes. Click to resume editing." : "Es gab ein Problem beim Speichern deiner Änderungen. Klicken um zur Bearbeitung zurückzukehren.",
-    "An error occurred!" : "Es ist ein Fehler aufgetreten!"
+    "An error occurred!" : "Es ist ein Fehler aufgetreten!",
+    "Text file" : "Textdatei",
+    "New text file.txt" : "Neue Textdatei.txt"
 },
 "nplurals=2; plural=(n != 1);");
