@@ -1,25 +1,7 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Kunne ikke sende mail til følgende brugere: %s",
-    "Preparing update" : "Forbereder opdatering",
-    "Turned on maintenance mode" : "Startede vedligeholdelsestilstand",
-    "Turned off maintenance mode" : "standsede vedligeholdelsestilstand",
-    "Maintenance mode is kept active" : "Vedligeholdelsestilstanden holdes kørende",
-    "Updating database schema" : "Opdaterer database schema",
-    "Updated database" : "Opdaterede database",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tjekker om database schema'et kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
-    "Checked database schema update" : "Tjekket database schema opdatering",
-    "Checking updates of apps" : "Tjekker opdatering af apps",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tjekker om database schema'et for %s kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
-    "Checked database schema update for apps" : "Tjekkede databaseskemaets opdatering for apps",
-    "Updated \"%s\" to %s" : "Opdaterede \"%s\" til %s",
-    "Repair warning: " : "Reparationsadvarsel:",
-    "Repair error: " : "Reparationsfejl:",
-    "%s (3rdparty)" : "%s (3rdparty)",
-    "%s (incompatible)" : "%s (inkombatible)",
-    "Following apps have been disabled: %s" : "Følgende apps er blevet deaktiveret: %s",
-    "Already up to date" : "Allerede opdateret",
+    "Please select a file." : "Vælg fil",
     "File is too big" : "Filen er for stor",
     "Invalid file provided" : "Der er angivet en ugyldig fil",
     "No image or file provided" : "Ingen fil eller billede givet",
@@ -33,8 +15,40 @@ OC.L10N.register(
     "Couldn't reset password because the token is invalid" : "Kunne ikke nulstille kodeordet, fordi symboludtrykket er ugyldigt",
     "Couldn't reset password because the token is expired" : "Kunne ikke nulstille kodeord, da tokenet er udløbet",
     "Couldn't send reset email. Please make sure your username is correct." : "Der opstod et problem under afsendelse af nulstillings-e-mailen. Kontroller venligst om dit brugernavnet er korrekt",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Kunne ikke sende e-mail om nulstilling af kodeord, da der ikke er knyttet en e-mail-adresse til dette brugernavn. Kontakt venligst din administrator.",
     "%s password reset" : "%s adgangskode nulstillet",
     "Couldn't send reset email. Please contact your administrator." : "Der opstod et problem under afsending af e-mailen til nulstilling. Kontakt venligst systemadministratoren.",
+    "Error loading tags" : "Fejl ved indlæsning af mærker",
+    "Tag already exists" : "Mærket eksisterer allerede",
+    "Error deleting tag(s)" : "Fejl ved sletning af mærke(r)",
+    "Error tagging" : "Fejl ved opmærkning",
+    "Error untagging" : "Fejl ved fjernelse af opmærkning",
+    "Error favoriting" : "Fejl ved omdannelse til foretrukken",
+    "Error unfavoriting" : "Fejl ved fjernelse fra foretrukken.",
+    "Couldn't send mail to following users: %s " : "Kunne ikke sende mail til følgende brugere: %s",
+    "Preparing update" : "Forbereder opdatering",
+    "Repair warning: " : "Reparationsadvarsel:",
+    "Repair error: " : "Reparationsfejl:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Brug kommandolinje-updateren, da automatisk opdatering er slået fra i config.php",
+    "Turned on maintenance mode" : "Startede vedligeholdelsestilstand",
+    "Turned off maintenance mode" : "standsede vedligeholdelsestilstand",
+    "Maintenance mode is kept active" : "Vedligeholdelsestilstanden holdes kørende",
+    "Updating database schema" : "Opdaterer database schema",
+    "Updated database" : "Opdaterede database",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tjekker om database schema'et kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
+    "Checked database schema update" : "Tjekket database schema opdatering",
+    "Checking updates of apps" : "Tjekker opdatering af apps",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tjekker om database schema'et for %s kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
+    "Checked database schema update for apps" : "Tjekkede databaseskemaets opdatering for apps",
+    "Updated \"%s\" to %s" : "Opdaterede \"%s\" til %s",
+    "Set log level to debug" : "Sæt logningsniveau til fejlfinding",
+    "Reset log level" : "Nulstil logningsniveau",
+    "Starting code integrity check" : "Begynder tjek af kodeintegritet",
+    "Finished code integrity check" : "Fuldførte tjek af kodeintegritet",
+    "%s (3rdparty)" : "%s (3rdparty)",
+    "%s (incompatible)" : "%s (inkombatible)",
+    "Following apps have been disabled: %s" : "Følgende apps er blevet deaktiveret: %s",
+    "Already up to date" : "Allerede opdateret",
     "Sunday" : "Søndag",
     "Monday" : "Mandag",
     "Tuesday" : "Tirsdag",
@@ -80,7 +94,9 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Der var problemer med integritetskontrollen af koden. Mere information...</a>",
     "Settings" : "Indstillinger",
+    "Problem loading page, reloading in 5 seconds" : "Problem med indlæsning af side, genindlæser om 5 sekunder",
     "Saving..." : "Gemmer...",
     "Dismiss" : "Afvis",
     "seconds ago" : "sekunder siden",
@@ -113,9 +129,16 @@ OC.L10N.register(
     "Strong password" : "Stærkt kodeord",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Din webserver er endnu ikke sat korrekt op til at tillade filsynkronisering, fordi WebDAV-grænsefladen ser ud til at være i stykker.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Denne ownCloud-server har ikke en fungerende forbindelse til internettet. Det betyder, at visse funktioner som montering af eksterne drev, oplysninger om opdatering eller installation af applikationer fra tredjepart ikke fungerer. Det vil sandsynligvis heller ikke være muligt at tilgå filer fra eksterne drev eller afsendelse af e-mail med notifikationer virker sandsynligvis heller ikke. Vi opfordrer til at etablere forbindelse til internettet for denne server, såfremt du ønsker samtlige funktioner.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Der er ikke konfigureret noget hukommelsesmellemlager. For at forbedre din ydelse bør du om muligt konfigurere en mamcache. Yderligere information findes i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentationen</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom kan ikke læses af PHP, hvilket stærkt frarådes af sikkerhedsgrunde. Yderligere information kan findes i vores <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentation</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Du kører i øjeblikket med PHP {version}. Vi anbefaler dig at opgradere din PHP version for at få glæde af <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">ydelses- og sikkerhedsopdateringer udgivet af the PHP Group</a> så snart din dintribution understøtter dem.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Konfigurationen af reverse proxy-headere er ikke korrekt eller du tilgår ownCloud fra en betroet proxy. Hvis du ikke tilgår ownCloud fra en betroet proxy, så er dette et sikkerhedsproblem og kan tillade en angriber af forfalske deres IP-adresse som synlig for ownCloud. Yderligere information kan findes i vores <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentation</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached er konfigureret som et distribueret mellemlager, men det forkerte PHP-modul \"memcache\" er installeret. \\OC\\Memcache\\Memcached understøtter kun \"memcached\" og ikke \"memcache\". Se <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached-wikien om begge moduler</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Nogle filer har ikke bestået integritetskontrollen. Yderligere information om hvordan man løser dette problem kan findes i vores <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dodumentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste over ugyldige filer...</a> / <a href=\"{rescanEndpoint}\">Scan igen…</a>)",
     "Error occurred while checking server setup" : "Der opstod fejl under tjek af serveropsætningen",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Din data mappe og dine filer er muligvis tilgængelige fra internettet. Filen .htaccess fungerer ikke. Vi anbefaler på det kraftigste, at du konfigurerer din webserver således at datamappen ikke længere er tilgængelig, eller at du flytter datamappen uden for webserverens dokumentrod.  ",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP-hovedet \"{header}\" er ikke konfigureret til at være lig med \"{expected}\". Dette er en potentiel sikkerhedsrisiko, og vi anbefaler at du justerer denne indstilling.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "HTTP headeren \"Strict-Transport-Security\" er ikke konfigureret til mindst \"{seconds}\" sekunder. For bedre sikkerhed anbefaler vi at aktivere HSTS som beskrevet i vores <a href=\"{docUrl}\" rel=\"noreferrer\">sikkerhedstips</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du tilgår dette sted gennem HTTP. Vi anbefaler kraftigt at du konfigurerer din server, så der kræves brug af HTTPS i stedet for, som foreskrevet i vores <a href=\"{docUrl}\">sikkerhedstips</a>.",
     "Shared" : "Delt",
     "Shared with {recipients}" : "Delt med {recipients}",
@@ -128,8 +151,6 @@ OC.L10N.register(
     "Expiration" : "Udløb",
     "Expiration date" : "Udløbsdato",
     "Choose a password for the public link" : "Vælg et kodeord til det offentlige link",
-    "Sending ..." : "Sender ...",
-    "Email sent" : "E-mail afsendt",
     "Resharing is not allowed" : "Videredeling ikke tilladt",
     "Share link" : "Del link",
     "Link" : "Link",
@@ -138,6 +159,9 @@ OC.L10N.register(
     "Allow editing" : "Tillad redigering",
     "Email link to person" : "E-mail link til person",
     "Send" : "Send",
+    "Sending ..." : "Sender ...",
+    "Email sent" : "E-mail afsendt",
+    "Send link via email" : "Send link via e-mail",
     "Shared with you and the group {group} by {owner}" : "Delt med dig og gruppen {group} af {owner}",
     "Shared with you by {owner}" : "Delt med dig af {owner}",
     "group" : "gruppe",
@@ -150,14 +174,23 @@ OC.L10N.register(
     "change" : "tilpas",
     "delete" : "slet",
     "access control" : "Adgangskontrol",
+    "Could not unshare" : "Kunne ikke ophæve deling",
     "Share details could not be loaded for this item." : "Detaljer for deling kunne ikke indlæses for dette element.",
-    "An error occured. Please try again" : "Der skete en fejl. Prøv venligst igen",
+    "No users or groups found for {search}" : "Ingen brugere eller grupper fundet for {search}",
+    "No users found for {search}" : "Ingen brugere fundet for {search}",
+    "An error occurred. Please try again" : "Der opstor den fejl. Prøv igen",
     "Share" : "Del",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Del med andre på ownCloud ved hjælp af syntaxen username@example.com/owncloud",
-    "Share with users or groups …" : "Del med brugere eller grupper",
-    "Share with users, groups or remote users …" : "Del med brugere, grupper eller eksterne brugere...",
+    "Share with users…" : "Del med brugere...",
+    "Share with users, groups or remote users…" : "Del med brugere, grupper eller eksterne brugere...",
+    "Share with users or groups…" : "Del med brugere eller grupper...",
+    "Share with users or remote users…" : "Del med brugere eller eksterne brugere...",
+    "Error removing share" : "Fejl ved fjernelse af deling",
     "Warning" : "Advarsel",
     "Error while sending notification" : "Fejl ved afsendelse af notifikation",
+    "Non-existing tag #{tag}" : "Ikke-eksisterende mærke #{tag}",
+    "restricted" : "begrænset",
+    "invisible" : "usynlig",
     "Delete" : "Slet",
     "Rename" : "Omdøb",
     "The object type is not specified." : "Objekttypen er ikke angivet.",
@@ -171,12 +204,12 @@ OC.L10N.register(
     "sunny" : "solrigt",
     "Hello {name}, the weather is {weather}" : "Hej {name}, vejret er {weather}",
     "Hello {name}" : "Hej {name}",
+    "new" : "ny",
     "_download %n file_::_download %n files_" : ["hent %n fil","hent %n filer"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Opgraderingen er i gang, forlader du denne side kan det afbryde processen.",
-    "Updating {productName} to version {version}, this may take a while." : "Opdaterer {productName} til version {version}, det kan tage et stykke tid.",
     "An error occurred." : "Der opstod en fejl.",
     "Please reload the page." : "Genindlæs venligst siden",
-    "The update was unsuccessful. " : "Opdateringen blev ikke gennemført.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Opdateringen blev ikke udført korrekt. Rapporter venligst problemet til <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownClouds fællesskabet</a>.",
     "The update was successful. There were warnings." : "Opdateringen blev gennemført. Der fremkom advarsler.",
     "The update was successful. Redirecting you to ownCloud now." : "Opdateringen blev udført korrekt. Du bliver nu viderestillet til ownCloud.",
     "Searching other places" : "Søger på andre steder",
@@ -187,13 +220,6 @@ OC.L10N.register(
     "Apps" : "Apps",
     "Admin" : "Admin",
     "Help" : "Hjælp",
-    "Error loading tags" : "Fejl ved indlæsning af mærker",
-    "Tag already exists" : "Mærket eksisterer allerede",
-    "Error deleting tag(s)" : "Fejl ved sletning af mærke(r)",
-    "Error tagging" : "Fejl ved opmærkning",
-    "Error untagging" : "Fejl ved fjernelse af opmærkning",
-    "Error favoriting" : "Fejl ved omdannelse til foretrukken",
-    "Error unfavoriting" : "Fejl ved fjernelse fra foretrukken.",
     "Access forbidden" : "Adgang forbudt",
     "File not found" : "Filen blev ikke fundet",
     "The specified document has not been found on the server." : "Det angivne dokument blev ikke fundet på serveren.",
@@ -216,7 +242,6 @@ OC.L10N.register(
     "Trace" : "Sporing",
     "Security warning" : "Sikkerheds advarsel",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dine data mappe og filer er sandsynligvis tilgængelige fra internettet fordi .htaccess filen ikke virker.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "For information om, hvordan du konfigurerer din server korrekt se <a href=\"%s\" target=\"_blank\">dokumentationen</a>.",
     "Create an <strong>admin account</strong>" : "Opret en <strong>administratorkonto</strong>",
     "Username" : "Brugernavn",
     "Storage & database" : "Lager & database",
@@ -244,10 +269,10 @@ OC.L10N.register(
     "Search" : "Søg",
     "Server side authentication failed!" : "Server side godkendelse mislykkedes!",
     "Please contact your administrator." : "Kontakt venligst din administrator",
-    "An internal error occured." : "Der skete en intern fejl.",
     "Please try again or contact your administrator." : "Kontakt venligst din administrator.",
     "Log in" : "Log ind",
     "Wrong password. Reset it?" : "Forkert kodeord. Skal det nulstilles?",
+    "Wrong password." : "Forkert kodeord.",
     "Stay logged in" : "Forbliv logget ind",
     "Alternative Logins" : "Alternative logins",
     "Use the following link to reset your password: {link}" : "Anvend følgende link til at nulstille din adgangskode: {link}",
@@ -270,10 +295,6 @@ OC.L10N.register(
     "Start update" : "Begynd opdatering",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For at undgå tidsudløb ved større installationer, så kan du i stedet køre følgende kommando fra din installationsmappe:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instans befinder sig i vedligeholdelsestilstand for øjeblikket, hvilket kan tage et stykke tid.",
-    "This page will refresh itself when the %s instance is available again." : "Denne side vil genopfriske sig selv, når %s-instancen er tilgængelig igen.",
-    "Error loading file picker template: {error}" : "Fejl ved indlæsning af filvælger skabelon: {error}",
-    "Error removing share" : "Fejl ved fjernelse af deling",
-    "invisible" : "usynlig",
-    "Password can not be changed. Please contact your administrator." : "Adgangskoden kunne ikke ændres. Kontakt venligst din administrator."
+    "This page will refresh itself when the %s instance is available again." : "Denne side vil genopfriske sig selv, når %s-instancen er tilgængelig igen."
 },
 "nplurals=2; plural=(n != 1);");
