@@ -1,25 +1,7 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "%s 님에게 메일을 보낼 수 없습니다.",
-    "Preparing update" : "업데이트 준비 중",
-    "Turned on maintenance mode" : "유지 보수 모드 켜짐",
-    "Turned off maintenance mode" : "유지 보수 모드 꺼짐",
-    "Maintenance mode is kept active" : "유지 보수 모드가 켜져 있음",
-    "Updating database schema" : "데이터베이스 스키마 업데이트 중",
-    "Updated database" : "데이터베이스 업데이트 됨",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
-    "Checked database schema update" : "데이터베이스 스키마 업데이트 확인됨",
-    "Checking updates of apps" : "앱 업데이트 확인 중",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s의 데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
-    "Checked database schema update for apps" : "앱용 데이터베이스 스키마 업데이트 확인됨",
-    "Updated \"%s\" to %s" : "\"%s\"을(를) %s(으)로 업데이트함",
-    "Repair warning: " : "수리 경고:",
-    "Repair error: " : "수리 오류:",
-    "%s (3rdparty)" : "%s(제 3사)",
-    "%s (incompatible)" : "%s(호환 불가)",
-    "Following apps have been disabled: %s" : "다음 앱이 비활성화되었습니다: %s",
-    "Already up to date" : "최신 상태임",
+    "Please select a file." : "파일을 선택하십시오.",
     "File is too big" : "파일이 너무 큼",
     "Invalid file provided" : "잘못된 파일 지정됨",
     "No image or file provided" : "사진이나 파일이 없음",
@@ -33,8 +15,39 @@ OC.L10N.register(
     "Couldn't reset password because the token is invalid" : "토큰이 잘못되었기 때문에 암호를 초기화할 수 없습니다",
     "Couldn't reset password because the token is expired" : "토큰이 만료되어 암호를 초기화할 수 없습니다",
     "Couldn't send reset email. Please make sure your username is correct." : "재설정 메일을 보낼 수 없습니다. 사용자 이름이 올바른지 확인하십시오.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "이 사용자 이름과 연결된 이메일 주소가 없어서 초기화 메일을 보낼 수 없습니다. 시스템 관리자에게 연락하십시오.",
     "%s password reset" : "%s 암호 재설정",
     "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼수 없습니다. 관리자에게 문의하십시오.",
+    "Error loading tags" : "태그 불러오기 오류",
+    "Tag already exists" : "태그가 이미 존재합니다",
+    "Error deleting tag(s)" : "태그 삭제 오류",
+    "Error tagging" : "태그 추가 오류",
+    "Error untagging" : "태그 해제 오류",
+    "Error favoriting" : "즐겨찾기 추가 오류",
+    "Error unfavoriting" : "즐겨찾기 삭제 오류",
+    "Couldn't send mail to following users: %s " : "%s 님에게 메일을 보낼 수 없습니다.",
+    "Preparing update" : "업데이트 준비 중",
+    "Repair warning: " : "수리 경고:",
+    "Repair error: " : "수리 오류:",
+    "Turned on maintenance mode" : "유지 보수 모드 켜짐",
+    "Turned off maintenance mode" : "유지 보수 모드 꺼짐",
+    "Maintenance mode is kept active" : "유지 보수 모드가 켜져 있음",
+    "Updating database schema" : "데이터베이스 스키마 업데이트 중",
+    "Updated database" : "데이터베이스 업데이트 됨",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
+    "Checked database schema update" : "데이터베이스 스키마 업데이트 확인됨",
+    "Checking updates of apps" : "앱 업데이트 확인 중",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s의 데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
+    "Checked database schema update for apps" : "앱용 데이터베이스 스키마 업데이트 확인됨",
+    "Updated \"%s\" to %s" : "\"%s\"을(를) %s(으)로 업데이트함",
+    "Set log level to debug" : "로그 단계를 디버그로 설정",
+    "Reset log level" : "로그 단계 초기화",
+    "Starting code integrity check" : "코드 무결성 검사 시작 중",
+    "Finished code integrity check" : "코드 무결성 검사 완료됨",
+    "%s (3rdparty)" : "%s(제 3사)",
+    "%s (incompatible)" : "%s(호환 불가)",
+    "Following apps have been disabled: %s" : "다음 앱이 비활성화되었습니다: %s",
+    "Already up to date" : "최신 상태임",
     "Sunday" : "일요일",
     "Monday" : "월요일",
     "Tuesday" : "화요일",
@@ -80,6 +93,7 @@ OC.L10N.register(
     "Oct." : "10월",
     "Nov." : "11월",
     "Dec." : "12월",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">코드 무결성 검사 중 오류가 발생했습니다. 더 많은 정보를 보려면 누르십시오…</a>",
     "Settings" : "설정",
     "Saving..." : "저장 중...",
     "Dismiss" : "닫기",
@@ -128,8 +142,6 @@ OC.L10N.register(
     "Expiration" : "만료",
     "Expiration date" : "만료 날짜",
     "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
-    "Sending ..." : "전송 중...",
-    "Email sent" : "이메일 발송됨",
     "Resharing is not allowed" : "다시 공유할 수 없습니다",
     "Share link" : "링크 공유",
     "Link" : "링크",
@@ -138,6 +150,8 @@ OC.L10N.register(
     "Allow editing" : "편집 허용",
     "Email link to person" : "이메일 주소",
     "Send" : "전송",
+    "Sending ..." : "전송 중...",
+    "Email sent" : "이메일 발송됨",
     "Shared with you and the group {group} by {owner}" : "{owner} 님이 여러분 및 그룹 {group}와(과) 공유 중",
     "Shared with you by {owner}" : "{owner} 님이 공유 중",
     "group" : "그룹",
@@ -150,16 +164,23 @@ OC.L10N.register(
     "change" : "변경",
     "delete" : "삭제",
     "access control" : "접근 제어",
+    "Could not unshare" : "공유 해제할 수 없음",
     "Share details could not be loaded for this item." : "이 항목의 공유 정보를 불러올 수 없습니다.",
-    "An error occured. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
+    "No users or groups found for {search}" : "{search}에 해당하는 사용자나 그룹을 찾을 수 없음",
+    "{sharee} (group)" : "{sharee}(그룹)",
+    "{sharee} (at {server})" : "{sharee}({server}에 있음)",
+    "{sharee} (remote)" : "{sharee}(원격)",
     "Share" : "공유",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "username@example.com/owncloud 형식으로 다른 ownCloud 사용자와 공유할 수 있습니다",
-    "Share with users or groups …" : "사용자 및 그룹과 공유...",
-    "Share with users, groups or remote users …" : "사용자, 그룹 및 원격 사용자와 공유...",
+    "Error removing share" : "공유 삭제 중 오류 발생",
     "Warning" : "경고",
     "Error while sending notification" : "알림을 보내는 중 오류 발생",
+    "Non-existing tag #{tag}" : "존재하지 않는 태그 #{tag}",
+    "invisible" : "보이지 않음",
+    "({scope})" : "({scope})",
     "Delete" : "삭제",
     "Rename" : "이름 바꾸기",
+    "Collaborative tags" : "협동 태그",
     "The object type is not specified." : "객체 유형이 지정되지 않았습니다.",
     "Enter new" : "새로운 값 입력",
     "Add" : "추가",
@@ -171,12 +192,13 @@ OC.L10N.register(
     "sunny" : "맑음",
     "Hello {name}, the weather is {weather}" : "{name} 님 안녕하세요, 오늘 날씨는 {weather}입니다",
     "Hello {name}" : "{name} 님 안녕하세요",
+    "new" : "새로운 항목",
     "_download %n file_::_download %n files_" : ["파일 %n개 다운로드"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "업그레이드 중입니다. 이 페이지를 열어 두면 일부 환경에서 진행 과정을 중단시킬 수 있습니다.",
-    "Updating {productName} to version {version}, this may take a while." : "{productName}을(를) 버전 {version}으로 업데이트하고 있습니다. 시간이 걸릴 수 있습니다.",
     "An error occurred." : "오류가 발생했습니다.",
     "Please reload the page." : "페이지를 새로 고치십시오.",
-    "The update was unsuccessful. " : "업데이트가 실패했습니다. ",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "업데이트에 실패했습니다. 더 많은 정보를 보려면 이 문제를 다루은 <a href=\"{url}\">포럼 글</a>을 참조하십시오.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "업데이트가 실패하였습니다. 이 문제를 <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud 커뮤니티</a>에 보고해 주십시오.",
     "The update was successful. There were warnings." : "업데이트가 성공했습니다. 일부 경고가 있습니다.",
     "The update was successful. Redirecting you to ownCloud now." : "업데이트가 성공했습니다. ownCloud로 돌아갑니다.",
     "Searching other places" : "다른 장소 찾는 중",
@@ -187,13 +209,6 @@ OC.L10N.register(
     "Apps" : "앱",
     "Admin" : "관리자",
     "Help" : "도움말",
-    "Error loading tags" : "태그 불러오기 오류",
-    "Tag already exists" : "태그가 이미 존재합니다",
-    "Error deleting tag(s)" : "태그 삭제 오류",
-    "Error tagging" : "태그 추가 오류",
-    "Error untagging" : "태그 해제 오류",
-    "Error favoriting" : "즐겨찾기 추가 오류",
-    "Error unfavoriting" : "즐겨찾기 삭제 오류",
     "Access forbidden" : "접근 금지됨",
     "File not found" : "파일을 찾을 수 없음",
     "The specified document has not been found on the server." : "지정한 문서를 서버에서 찾을 수 없습니다.",
@@ -216,7 +231,6 @@ OC.L10N.register(
     "Trace" : "추적",
     "Security warning" : "보안 경고",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess 파일이 처리되지 않아서 데이터 디렉터리와 파일을 인터넷에서 접근할 수 없을 수도 있습니다.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "올바른 서버 설정을 위한 정보는 <a href=\"%s\" target=\"_blank\">문서</a>를 참조하십시오.",
     "Create an <strong>admin account</strong>" : "<strong>관리자 계정</strong> 만들기",
     "Username" : "사용자 이름",
     "Storage & database" : "저장소 및 데이터베이스",
@@ -244,10 +258,10 @@ OC.L10N.register(
     "Search" : "검색",
     "Server side authentication failed!" : "서버 인증 실패!",
     "Please contact your administrator." : "관리자에게 문의하십시오.",
-    "An internal error occured." : "내부 오류가 발생했습니다.",
     "Please try again or contact your administrator." : "다시 시도하거나 관리자에게 연락하십시오.",
     "Log in" : "로그인",
     "Wrong password. Reset it?" : "암호가 잘못되었습니다. 다시 설정하시겠습니까?",
+    "Wrong password." : "암호가 잘못되었습니다.",
     "Stay logged in" : "로그인 유지",
     "Alternative Logins" : "대체 로그인",
     "Use the following link to reset your password: {link}" : "다음 링크를 사용하여 암호를 재설정할 수 있습니다: {link}",
@@ -259,6 +273,7 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나, 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오",
     "Thank you for your patience." : "기다려 주셔서 감사합니다.",
     "You are accessing the server from an untrusted domain." : "신뢰할 수 없는 도메인으로 서버에 접근하고 있습니다.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "시스템 관리자에게 연락하십시오. 만약 이 인스턴스의 관리자라면 config/config.php에서 \"trusted_domains\" 설정을 편집하십시오. config/config.sample.php에 있는 예제 설정을 참고하십시오.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "설정에 따라서 관리자 권한으로 아래 단추를 눌러서 이 도메인을 신뢰하도록 설정할 수 있습니다.",
     "Add \"%s\" as trusted domain" : "\"%s\"을(를) 신뢰할 수 있는 도메인으로 추가",
     "App update required" : "앱 업데이트 필요",
