@@ -1,27 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Ni mogoče poslati sporočila za: %s",
-    "Preparing update" : "Pripravljanje posodobitve",
-    "Turned on maintenance mode" : "Vzdrževalni način je omogočen",
-    "Turned off maintenance mode" : "Vzdrževalni način je onemogočen",
-    "Maintenance mode is kept active" : "Vzdrževalni način je še vedno dejaven",
-    "Updating database schema" : "Poteka posodabljanje sheme podatkovne zbirke",
-    "Updated database" : "Posodobljena podatkovna zbirka",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Preverjam, ali lahko posodobim strukturo baze (lahko traja dlje zaradi velikosti baze)",
-    "Checked database schema update" : "Izbrana posodobitev sheme podatkovne zbirke",
-    "Checking updates of apps" : "Poteka preverjanje za posodobitve programov",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Preverjam, ali lahko posodobim strukturo baze za %s (lahko traja dlje zaradi velikosti baze)",
-    "Checked database schema update for apps" : "Izbrana posodobitev sheme podatkovne zbirke za programe",
-    "Updated \"%s\" to %s" : "Datoteka \"%s\" je posodobljena na %s",
-    "Repair warning: " : "Opozorilo popravila:",
-    "Repair error: " : "Napaka popravila:",
-    "Set log level to debug" : "Nastavi raven beleženja za razhroščevanje",
-    "Reset log level" : "Počisti raven beleženja",
-    "%s (3rdparty)" : "%s (zunanje)",
-    "%s (incompatible)" : "%s (neskladno)",
-    "Following apps have been disabled: %s" : "Navedeni programi so onemogočeni: %s",
-    "Already up to date" : "Sistem je že posodobljen",
     "Please select a file." : "Izberite datoteko",
     "File is too big" : "Datoteka je prevelika",
     "Invalid file provided" : "Predložena je neveljavna datoteka",
@@ -31,13 +10,47 @@ OC.L10N.register(
     "An error occurred. Please contact your admin." : "Prišlo je do napake. Stopite v stik s skrbnikom sistema.",
     "No temporary profile picture available, try again" : "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
     "No crop data provided" : "Ni podanih podatkov obreza",
-    "No valid crop data provided" : "Napačni podatki za obrez slike",
+    "No valid crop data provided" : "Navedeni so neveljavni podatki obrez slike",
     "Crop is not square" : "Obrez ni pravokoten",
     "Couldn't reset password because the token is invalid" : "Ni mogoče ponastaviti gesla zaradi neustreznega žetona.",
     "Couldn't reset password because the token is expired" : "Ni mogoče ponastaviti gesla, ker je žeton potekel.",
     "Couldn't send reset email. Please make sure your username is correct." : "Ni mogoče poslati elektronskega sporočila. Prepričajte se, da je uporabniško ime pravilno.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Ni mogoče poslati elektronskega sporočila za ponastavitev gesla, ker ni navedenega elektronskega naslova. Stopite v stik s skrbnikom sistema.",
     "%s password reset" : "Ponastavitev gesla %s",
     "Couldn't send reset email. Please contact your administrator." : "Ni mogoče nastaviti elektronskega naslova za ponastavitev. Stopite v stik s skrbnikom sistema.",
+    "Error loading tags" : "Napaka nalaganja oznak",
+    "Tag already exists" : "Oznaka že obstaja",
+    "Error deleting tag(s)" : "Napaka brisanja oznak",
+    "Error tagging" : "Napaka označevanja",
+    "Error untagging" : "Napaka odstranjevanja oznak",
+    "Error favoriting" : "Napaka označevanja priljubljenosti",
+    "Error unfavoriting" : "Napaka odstranjevanja oznake priljubljenosti",
+    "Couldn't send mail to following users: %s " : "Ni mogoče poslati sporočila za: %s",
+    "Preparing update" : "Pripravljanje posodobitve",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Opozorilo popravila:",
+    "Repair error: " : "Napaka popravila:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Posodobitev sistema je treba izvesti prek ukazne vrstice, ker je nastavitev samodejne posodobitve v config.php onemogočena.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Poteka preverjanje razpredelnice %s",
+    "Turned on maintenance mode" : "Vzdrževalni način je omogočen",
+    "Turned off maintenance mode" : "Vzdrževalni način je onemogočen",
+    "Maintenance mode is kept active" : "Vzdrževalni način je še vedno dejaven",
+    "Updating database schema" : "Poteka posodabljanje sheme podatkovne zbirke",
+    "Updated database" : "Posodobljena podatkovna zbirka",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke mogoče posodobiti (zaradi velikosti je lahko opravilo dolgotrajno).",
+    "Checked database schema update" : "Izbrana posodobitev sheme podatkovne zbirke",
+    "Checking updates of apps" : "Poteka preverjanje za posodobitve programov",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke za %s mogoče posodobiti (trajanje posodobitve je odvisno od velikosti zbirke).",
+    "Checked database schema update for apps" : "Izbrana posodobitev sheme podatkovne zbirke za programe",
+    "Updated \"%s\" to %s" : "Datoteka \"%s\" je posodobljena na %s",
+    "Set log level to debug" : "Nastavi raven beleženja za razhroščevanje",
+    "Reset log level" : "Počisti raven beleženja",
+    "Starting code integrity check" : "Začenjanje preverjanja stanja kode",
+    "Finished code integrity check" : "Končano preverjanje stanja kode",
+    "%s (3rdparty)" : "%s (zunanje)",
+    "%s (incompatible)" : "%s (neskladno)",
+    "Following apps have been disabled: %s" : "Navedeni programi so onemogočeni: %s",
+    "Already up to date" : "Sistem je že posodobljen",
     "Sunday" : "nedelja",
     "Monday" : "ponedeljek",
     "Tuesday" : "torek",
@@ -83,7 +96,9 @@ OC.L10N.register(
     "Oct." : "okt",
     "Nov." : "nov",
     "Dec." : "dec",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Med preverjanjem celovitosti kode je prišlo do napak. Več podrobnosti …</a>",
     "Settings" : "Nastavitve",
+    "Problem loading page, reloading in 5 seconds" : "Napaka nalaganja strani! Poskus ponovnega nalaganja bo izveden čez 5 sekund.",
     "Saving..." : "Poteka shranjevanje ...",
     "Dismiss" : "Opusti",
     "seconds ago" : "pred nekaj sekundami",
@@ -114,7 +129,17 @@ OC.L10N.register(
     "So-so password" : "Slabo geslo",
     "Good password" : "Dobro geslo",
     "Strong password" : "Odlično geslo",
+    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Spletni stražnik še ni ustrezno nastavljen in ne omogoča usklajevanja, saj je vmesnik WebDAV videti okvarjen.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Spletni strežnik ni ustrezno nastavljen za razreševanje \"{url}\". Več pdorobnosti je zapisanih v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji</a>.",
+    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Strežnik je brez vzpostavljene internetne povezave. To pomeni, da priklapljanje zunanjih diskov,  opozorila za posodobitve in namestitve programske opreme iz drugih virov, niso mogoče. Za popolno delovanje OwnCloud je nujna delujoča internetna povezava.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Ni nastavljenega predpomnilnika. Za izboljšanje hitrosti delovanja je treba predpomnilnik memcache, če je na voljo, ustrezno nastaviti. Več podrobnosti je na voljo v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Iz varnostnih razlogov je priporočljivo nastaviti dovoljenja ukaza /dev/urandom za branje prek PHP. Več podrobnosti je zavedenih v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji<-a>",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Trenutno je zagnana različica PHP {version}. Priporočljivo je posodobiti sistem na najnovejšo različico in s tem namestiti <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">funkcijske in varnostne posodobitve delovanja, ki jih zagotavlja skupnost PHP</a>. Pakete je priporočljivo posodobiti takoj, ko so na voljo za nameščeno distribucijo.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Predpomnilnik memcached je nastavljen kot porazdeljen predpomnilnik, vendar pa je nameščen napačen modul PHP \"memcache\". Modul \\OC\\Memcache\\Memcached podpirao le \"memcached\", ne pa tudi \"memcache\". Več podrobnosti za oba modula je zapisanih  <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">na wiki straneh</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Nekatere datoteke ne opravijo preizkusa celovitosti. Več podrobnosti o težavi je opisanih v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Seznam neveljavnih datotek …</a> / <a href=\"{rescanEndpoint}\">Ponovni preizkus …</a>)",
     "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Podatkovna mapa in datoteke so najverjetneje dostopni prek Interneta, ker datoteka .htaccess ni ustrezno nastavljena. Priporočljivo je nastaviti spletni strežnik tako, da dostop prek zunanjega omrežja ni mogoč, ali pa tako, da podatkovna mapa ni znotraj korenske mape strežnika.",
+    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Do spletišča je omogočen dostop prek protokola HTTP. Priporočljivo je omogočiti podporo za varni protokol HTTPS. Več podrobnosti je zapisanih med <a href=\"{docUrl}\">varnostnimi namigi</a>.",
     "Shared" : "V souporabi",
     "Shared with {recipients}" : "V souporabi z {recipients}",
     "Error" : "Napaka",
@@ -126,8 +151,6 @@ OC.L10N.register(
     "Expiration" : "Datum preteka",
     "Expiration date" : "Datum preteka",
     "Choose a password for the public link" : "Izberite geslo za javno povezavo",
-    "Sending ..." : "Pošiljanje ...",
-    "Email sent" : "Elektronska pošta je poslana",
     "Resharing is not allowed" : "Nadaljnja souporaba ni dovoljena",
     "Share link" : "Povezava za prejem",
     "Link" : "Povezava",
@@ -136,6 +159,9 @@ OC.L10N.register(
     "Allow editing" : "Dovoli urejanje",
     "Email link to person" : "Posreduj povezavo po elektronski pošti",
     "Send" : "Pošlji",
+    "Sending ..." : "Pošiljanje ...",
+    "Email sent" : "Elektronska pošta je poslana",
+    "Send link via email" : "Pošlji povezavo prek elektronske pošte",
     "Shared with you and the group {group} by {owner}" : "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
     "Shared with you by {owner}" : "V souporabi z vami. Lastnik je {owner}.",
     "group" : "skupina",
@@ -148,16 +174,30 @@ OC.L10N.register(
     "change" : "sprememba",
     "delete" : "izbriše",
     "access control" : "nadzor dostopa",
-    "Share details could not be loaded for this item." : "Detajlov souporabe ne morem naložiti za ta element.",
-    "An error occured. Please try again" : "Prišlo je do napake. Poskusite znova.",
+    "Could not unshare" : "Ni mogoče prekiniti souporabe",
+    "Share details could not be loaded for this item." : "Podrobnosti souporabe za te predmet ni mogoče naložiti.",
+    "No users or groups found for {search}" : "Ni najdenih uporabnikov ali skupin za {search}",
+    "No users found for {search}" : "Ni uporabnikov, skladnih z iskalnim nizom {search}",
+    "An error occurred. Please try again" : "Prišlo je do napake. Poskusite znova.",
+    "{sharee} (group)" : "{sharee} (skupina)",
+    "{sharee} (at {server})" : "{sharee} (na {server})",
+    "{sharee} (remote)" : "{sharee} (oddaljeno)",
     "Share" : "Souporaba",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Soupraba z ljudmi v drugih ownCloud oblakih v formatu uporabnik@domena.si/owncloud",
-    "Share with users or groups …" : "Souporaba z uporabniki ali skupinami ...",
-    "Share with users, groups or remote users …" : "Souporaba z usporabniki, skupinami ali zunanjimi uporabniki ...",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Souporaba z uporabniki, ki so na drugih oblakih ownCloud s povezavo uporabnik@domena.si/owncloud",
+    "Share with users…" : "Omogoči souporabo z ...",
+    "Share with users, groups or remote users…" : "Souporaba z uporabniki, skupinami ali zunanjimi uporabniki ...",
+    "Share with users or groups…" : "Souporaba z uporabniki ali skupinami ...",
+    "Share with users or remote users…" : "Souporaba z uporabniki ali oddaljenimi uporabniki ...",
+    "Error removing share" : "Napaka odstranjevanja souporabe",
     "Warning" : "Opozorilo",
     "Error while sending notification" : "Napaka med pošiljanjem obvestila",
+    "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
+    "restricted" : "omejeno",
+    "invisible" : "nevidno",
+    "({scope})" : "({scope})",
     "Delete" : "Izbriši",
     "Rename" : "Preimenuj",
+    "Collaborative tags" : "Oznake za sodelovanje",
     "The object type is not specified." : "Vrsta predmeta ni podana.",
     "Enter new" : "Vnesite novo",
     "Add" : "Dodaj",
@@ -169,13 +209,15 @@ OC.L10N.register(
     "sunny" : "sončno",
     "Hello {name}, the weather is {weather}" : "Pozdravljeni, {name}, vreme je {weather}",
     "Hello {name}" : "Pozdravljeni, {name}",
+    "new" : "novo",
     "_download %n file_::_download %n files_" : ["prejmi %n datoteko","prejmi %n datoteki","prejmi %n datoteke","prejmi %n datotek"],
-    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Posodobitev sistema je v teku. Če zapustite stran, lahko v nekaterih okoljih prekine ta proces.",
-    "Updating {productName} to version {version}, this may take a while." : "Poteka posodabljanje {productName} na različico {version}. Opravilo je lahko dolgotrajno.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Trenutno se izvaja posodobitev sistema. Priporočljivo je počakati, saj se lahko opravilo, če stran zapustite, prekine.",
+    "Updating to {version}" : "Posodabljanje na različico {version}",
     "An error occurred." : "Prišlo je do napake.",
     "Please reload the page." : "Stran je treba ponovno naložiti",
-    "The update was unsuccessful. " : "Posodobitev je spodletela.",
-    "The update was successful. There were warnings." : "Posodobitev je uspela. Z nekaj opozorili.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Posodobitev je spodletela. Za več podrobnosti o napaki je <a href=\"{url}\">objavljenih na forumu</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Posodobitev je spodletela uspela. Pošljite poročilo o napaki razvijalcem sistema <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud</a>.",
+    "The update was successful. There were warnings." : "Posodobitev je uspešno končana, vendar z nekaj opozorili.",
     "The update was successful. Redirecting you to ownCloud now." : "Posodobitev je uspešno končana. Stran bo preusmerjena na oblak ownCloud.",
     "Searching other places" : "Iskanje drugih mest",
     "No search results in other folders" : "Iskanje po drugih mapah ni vrnilo rezultata",
@@ -185,20 +227,13 @@ OC.L10N.register(
     "Apps" : "Programi",
     "Admin" : "Skrbništvo",
     "Help" : "Pomoč",
-    "Error loading tags" : "Napaka nalaganja oznak",
-    "Tag already exists" : "Oznaka že obstaja",
-    "Error deleting tag(s)" : "Napaka brisanja oznak",
-    "Error tagging" : "Napaka označevanja",
-    "Error untagging" : "Napaka odstranjevanja oznak",
-    "Error favoriting" : "Napaka označevanja priljubljenosti",
-    "Error unfavoriting" : "Napaka odstranjevanja oznake priljubljenosti",
     "Access forbidden" : "Dostop je prepovedan",
     "File not found" : "Datoteke ni mogoče najti",
     "The specified document has not been found on the server." : "Določenega dokumenta na strežniku ni mogoče najti.",
     "You can click here to return to %s." : "S klikom na povezavo boste vrnjeni na %s.",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Pozdravljeni,\n\noseba %s vam je omogočila souporabo %s.\nVir si lahko ogledate: %s\n\n",
     "The share will expire on %s." : "Povezava souporabe bo potekla %s.",
-    "Cheers!" : "Na zdravje!",
+    "Cheers!" : "Lep pozdrav!",
     "Internal Server Error" : "Notranja  napaka strežnika",
     "The server encountered an internal error and was unable to complete your request." : "Prišlo je do notranje napake, zato ni mogoče končati zahteve.",
     "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Stopite v stik s skrbnikom sistema, če se napaka pojavlja pogosto. V poročilo vključite tudi tehnične podatke v dnevniški datoteki.",
@@ -214,13 +249,15 @@ OC.L10N.register(
     "Trace" : "Sledenje povezav",
     "Security warning" : "Varnostno opozorilo",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni preko interneta, saj datoteka .htaccess ni ustrezno nastavljena.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Za več informacij o pravilnem nastavljanju strežnika, kliknite na povezavo do <a href=\"%s\" target=\"_blank\">dokumentacije</a>.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Za več podrobnosti o pravilnem nastavljanju strežnika si oglejte <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dokumentacijo</a>.",
     "Create an <strong>admin account</strong>" : "Ustvari <strong>skrbniški račun</strong>",
     "Username" : "Uporabniško ime",
     "Storage & database" : "Shramba in podatkovna zbirka",
     "Data folder" : "Podatkovna mapa",
     "Configure the database" : "Nastavi podatkovno zbirko",
     "Only %s is available." : "Le %s je na voljo.",
+    "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
+    "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
     "Database user" : "Uporabnik podatkovne zbirke",
     "Database password" : "Geslo podatkovne zbirke",
     "Database name" : "Ime podatkovne zbirke",
@@ -228,19 +265,23 @@ OC.L10N.register(
     "Database host" : "Gostitelj podatkovne zbirke",
     "Performance warning" : "Opozorilo učinkovitosti delovanja",
     "SQLite will be used as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite",
+    "For larger installations we recommend to choose a different database backend." : "Za večje namestitve je priporočljivo uporabiti drugo ozadnji program  zbirke podatkov.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Uporaba SQLite ni priporočljiva iz varnostnih razlogov, še posebej če se sistem krajevno usklajuje z namizjem prek odjemalca.",
     "Finish setup" : "Končaj nastavitev",
     "Finishing …" : "Poteka zaključevanje opravila ...",
     "Need help?" : "Ali potrebujete pomoč?",
     "See the documentation" : "Preverite dokumentacijo",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Pozdravljeni,<br><br>uporabnik %s vam je omogočil souporabo <strong>%s</strong>.<br><a href=\"%s\">Oglejte si vsebino!</a><br><br>",
+    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
     "Log out" : "Odjava",
     "Search" : "Poišči",
     "Server side authentication failed!" : "Overitev s strežnika je spodletela!",
     "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
-    "An internal error occured." : "Prišlo je do notranje napake.",
+    "An internal error occurred." : "Prišlo je do notranje napake.",
     "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
+    "Username or email" : "Uporabniško ime ali elektronski naslov",
     "Log in" : "Prijava",
-    "Wrong password. Reset it?" : "Napačno gelo. Ponastavimo?",
+    "Wrong password. Reset it?" : "Napačno geslo. Ali ga želite ponastaviti?",
     "Wrong password." : "Napačno geslo!",
     "Stay logged in" : "Ohrani prijavo",
     "Alternative Logins" : "Druge prijavne možnosti",
@@ -252,18 +293,25 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "To pomeni, da lahko oblak uporabljajo le osebe s skrbniškimi dovoljenji.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Stopite v stik s skrbnikom sistema, če se bo sporočilo še naprej nepričakovano prikazovalo.",
     "Thank you for your patience." : "Hvala za potrpežljivost!",
+    "Two-step verification" : "Dvostopenjsko overjanje",
+    "Cancel login" : "Prekliči prijavo",
+    "An error occured while verifying the token" : "Napaka se je zgodila med preverjanjem ključa",
     "You are accessing the server from an untrusted domain." : "Trenutno je vzpostavljena povezava s strežnikom preko ne-varne domene.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Glede na nastavitve bi lahko kot skrbnik uporabili spodnji gumb in domeno ročno določili kot varno.",
     "Add \"%s\" as trusted domain" : "Dodaj \"%s\" kot varno domeno",
     "App update required" : "Zahtevana je posodobitev programa",
-    "%s will be updated to version %s" : "%s bo posodbljena na verzijo %s",
-    "These apps will be updated:" : "Te aplikacije bodo posodbljene:",
-    "These incompatible apps will be disabled:" : "Te neskladne aplikacije bodo onemogočene:",
+    "%s will be updated to version %s" : "%s bo posodobljen na različico %s.",
+    "These apps will be updated:" : "Posodobljeni bodo naslednji vstavki:",
+    "These incompatible apps will be disabled:" : "Ti neskladni vstavki bodo onemogočeni:",
     "The theme %s has been disabled." : "Tema %s je onemogočena za uporabo.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred nadaljevanjem se prepričajte se, da je ustvarjena varnostna kopija podatkovne zbirke, nastavitvenih datotek in podatkovne mape.",
     "Start update" : "Začni posodobitev",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
-    "This %s instance is currently in maintenance mode, which may take a while." : "Ta %s strežnik je trenutno v načinu vzdrževanja, kar lahko traja dlje časa.",
+    "Detailed logs" : "Podrobni dnevniški zapisi",
+    "Update needed" : "Zahtevana je posodobitev",
+    "Please use the command line updater because you have a big instance." : "Posodobitev večjih namestitev je priporočljivo izvesti prek ukazne vrstice.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Za več podrobnosti si oglejte <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentacijo</a>.",
+    "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v načinu vzdrževanja, kar lahko traja.",
     "This page will refresh itself when the %s instance is available again." : "Stran bo osvežena ko bo %s spet na voljo."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
