@@ -1,23 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Неможливо надіслати листа наступним користувачам: %s ",
-    "Preparing update" : "Підготовка до оновлення",
-    "Turned on maintenance mode" : "Увімкнено режим технічного обслуговування",
-    "Turned off maintenance mode" : "Вимкнено режим технічного обслуговування",
-    "Maintenance mode is kept active" : "Режим обслуговування залишається активним",
-    "Updating database schema" : "Оновлення схеми бази даних",
-    "Updated database" : "Базу даних оновлено",
-    "Checked database schema update" : "Перевірено оновлення схеми бази даних",
-    "Checking updates of apps" : "Перевірка оновлень додатків",
-    "Checked database schema update for apps" : "Перевірено оновлення схеми бази даних для додатків",
-    "Updated \"%s\" to %s" : "Оновлено \"%s\" до %s",
-    "Repair warning: " : "Попередження відновлення:",
-    "Repair error: " : "Помилка відновлення:",
-    "Starting code integrity check" : "Початок перевірки цілісності коду",
-    "Finished code integrity check" : "Завершено перевірку цілісності коду",
-    "Following apps have been disabled: %s" : "Наступні додатки були вимкнені: %s",
-    "Already up to date" : "Актуально",
     "Please select a file." : "Будь ласка, оберіть файл.",
     "File is too big" : "Файл занадто великий",
     "Invalid file provided" : "Надано невірний файл",
@@ -32,8 +15,42 @@ OC.L10N.register(
     "Couldn't reset password because the token is invalid" : "Неможливо скинути пароль, бо маркер є недійсним",
     "Couldn't reset password because the token is expired" : "Неможливо скинути пароль, бо маркер застарів",
     "Couldn't send reset email. Please make sure your username is correct." : "Не вдалося відправити скидання паролю. Будь ласка, переконайтеся, що ваше ім'я користувача є правильним.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Не вдалося відправити скидання паролю, тому що немає адреси електронної пошти для цього користувача. Будь ласка, зверніться до адміністратора.",
     "%s password reset" : "%s скидання паролю",
     "Couldn't send reset email. Please contact your administrator." : "Не можу надіслати email для скидання. Будь ласка, зверніться до вашого адміністратора.",
+    "Error loading tags" : "Помилка завантаження міток",
+    "Tag already exists" : "Мітка вже існує",
+    "Error deleting tag(s)" : "Помилка видалення мітки(ок)",
+    "Error tagging" : "Помилка встановлення міток",
+    "Error untagging" : "Помилка зняття мітки",
+    "Error favoriting" : "Помилка додавання в улюблені",
+    "Error unfavoriting" : "Помилка видалення з улюбленого",
+    "Couldn't send mail to following users: %s " : "Неможливо надіслати листа наступним користувачам: %s ",
+    "Preparing update" : "Підготовка до оновлення",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Попередження відновлення:",
+    "Repair error: " : "Помилка відновлення:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Просимо запустити процес оновлення з командного рядка, оскільки автоматичне оновлення вимкнено у файлі config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Перевірка таблиці %s",
+    "Turned on maintenance mode" : "Увімкнено режим технічного обслуговування",
+    "Turned off maintenance mode" : "Вимкнено режим технічного обслуговування",
+    "Maintenance mode is kept active" : "Режим обслуговування залишається активним",
+    "Updating database schema" : "Оновлення схеми бази даних",
+    "Updated database" : "Базу даних оновлено",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Перевіряю, чи схема бази даних може бути оновлена (це може зайняти багато часу, залежно від розмірів бази даних)",
+    "Checked database schema update" : "Перевірено оновлення схеми бази даних",
+    "Checking updates of apps" : "Перевірка оновлень додатків",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Перевіряю, чи схема бази даних для %s може бути оновлена (це може зайняти багато часу, залежно від розмірів бази даних)",
+    "Checked database schema update for apps" : "Перевірено оновлення схеми бази даних для додатків",
+    "Updated \"%s\" to %s" : "Оновлено \"%s\" до %s",
+    "Set log level to debug" : "Встановити рівень детальності журналу як налагодження",
+    "Reset log level" : "Скинути налаштування детальності журналу",
+    "Starting code integrity check" : "Початок перевірки цілісності коду",
+    "Finished code integrity check" : "Завершено перевірку цілісності коду",
+    "%s (3rdparty)" : "%s (стороннє)",
+    "%s (incompatible)" : "%s (несумісне)",
+    "Following apps have been disabled: %s" : "Наступні додатки були вимкнені: %s",
+    "Already up to date" : "Вже актуально",
     "Sunday" : "Неділя",
     "Monday" : "Понеділок",
     "Tuesday" : "Вівторок",
@@ -79,7 +96,9 @@ OC.L10N.register(
     "Oct." : "Жов.",
     "Nov." : "Лис.",
     "Dec." : "Гру.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Були проблеми з перевіркою цілісності коду. Більше інформації…</a>",
     "Settings" : "Налаштування",
+    "Problem loading page, reloading in 5 seconds" : "Проблема під час завантаження сторінки, повторне завантаження за 5 сек.",
     "Saving..." : "Збереження...",
     "Dismiss" : "Припинити",
     "seconds ago" : "секунди тому",
@@ -126,8 +145,6 @@ OC.L10N.register(
     "Expiration" : "Закінчення",
     "Expiration date" : "Термін дії",
     "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
-    "Sending ..." : "Надсилання...",
-    "Email sent" : "Лист надіслано",
     "Resharing is not allowed" : "Пере-публікація не дозволяється",
     "Share link" : "Поділитись посиланням",
     "Link" : "Посилання",
@@ -136,6 +153,9 @@ OC.L10N.register(
     "Allow editing" : "Дозволити редагування",
     "Email link to person" : "Надіслати посилання електронною поштою",
     "Send" : "Надіслати",
+    "Sending ..." : "Надсилання...",
+    "Email sent" : "Лист надіслано",
+    "Send link via email" : "Надіслати посилання електронною поштою",
     "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
     "Shared with you by {owner}" : "{owner} опублікував для Вас",
     "group" : "група",
@@ -148,18 +168,29 @@ OC.L10N.register(
     "change" : "змінити",
     "delete" : "видалити",
     "access control" : "контроль доступу",
+    "Could not unshare" : "Неможливо припинити ділитися файлом",
     "No users or groups found for {search}" : "Не знайдено груп або користувачів за пошуком {search}",
-    "An error occured. Please try again" : "Виникла помилка. Будь ласка, спробуйте ще раз",
+    "No users found for {search}" : "Не знайдено жодного користувача для {search}",
+    "An error occurred. Please try again" : "Сталася помилка. Спробуйте ще раз",
     "{sharee} (group)" : "{sharee} (група)",
+    "{sharee} (at {server})" : "{sharee} (на {server})",
+    "{sharee} (remote)" : "{sharee} (віддалений)",
     "Share" : "Поділитися",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поширити серед людей інших ownCloud'ів, використовуючи синтаксис ім'я_користувача@файли.укр/owncloud",
-    "Share with users or groups …" : "Поширити серед користувачів або груп ...",
-    "Share with users, groups or remote users …" : "Поширити серед локальних чи віддалених користувачів або груп ...",
+    "Share with users…" : "Поділитись з користувачами...",
+    "Share with users, groups or remote users…" : "Поділитись з користувачами, групами або віддаленими користувачами...",
+    "Share with users or groups…" : "Поділитись з користувачами або групами...",
+    "Share with users or remote users…" : "Поділитись з користувачами системи або віддаленими користувачами...",
+    "Error removing share" : "Помилка під час вилучення спільного",
     "Warning" : "Попередження",
-    "Error while sending notification" : "Помилка при надсиланні повідомлення",
+    "Error while sending notification" : "Помилка під час надсилання повідомлення",
+    "Non-existing tag #{tag}" : "Ця позначка відсутня #{tag}",
+    "restricted" : "обмежено",
+    "invisible" : "невидимо",
     "({scope})" : "({scope})",
     "Delete" : "Видалити",
     "Rename" : "Перейменувати",
+    "Collaborative tags" : "Позначки для співпраці",
     "The object type is not specified." : "Не визначено тип об'єкту.",
     "Enter new" : "Введіть новий",
     "Add" : "Додати",
@@ -171,11 +202,14 @@ OC.L10N.register(
     "sunny" : "сонячно",
     "Hello {name}, the weather is {weather}" : "Привіт {name}, погода {weather} ",
     "Hello {name}" : "Привіт {name}",
+    "new" : "новий",
     "_download %n file_::_download %n files_" : ["завантаження %n файлу","завантаження %n файлів","завантаження %n файлів"],
-    "Updating {productName} to version {version}, this may take a while." : "Оновлення {productName} до версії {version}, це може займати деякий час.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Триває оновлення, якщо ви покинете сторінку, це може перервати процес в деяких оточеннях.",
+    "Updating to {version}" : "Оновлення до {version}",
     "An error occurred." : "Виникла помилка.",
     "Please reload the page." : "Будь ласка, перезавантажте сторінку.",
-    "The update was unsuccessful. " : "Оновлення завершилось невдачею.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Оновлення не вдалося. За інформацією <a href=\"{url}\">зверніться до повідомлення на форумі</a>, що описує цю проблему.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Оновлення виконалось неуспішно. Будь ласка, повідомте про цю проблему в <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">спільноту ownCloud</a>.",
     "The update was successful. There were warnings." : "Оновлення виконалось успішно, але були попередження.",
     "The update was successful. Redirecting you to ownCloud now." : "Оновлення виконалось успішно. Перенаправляємо вас на  ownCloud.",
     "Searching other places" : "Йде пошук в інших місцях",
@@ -186,13 +220,6 @@ OC.L10N.register(
     "Apps" : "Додатки",
     "Admin" : "Адмін",
     "Help" : "Допомога",
-    "Error loading tags" : "Помилка завантаження міток",
-    "Tag already exists" : "Мітка вже існує",
-    "Error deleting tag(s)" : "Помилка видалення мітки(ок)",
-    "Error tagging" : "Помилка встановлення міток",
-    "Error untagging" : "Помилка зняття мітки",
-    "Error favoriting" : "Помилка додавання в улюблені",
-    "Error unfavoriting" : "Помилка видалення з улюбленого",
     "Access forbidden" : "Доступ заборонено",
     "File not found" : "Файл не знайдено",
     "The specified document has not been found on the server." : "Не вдалось знайти вказаний документ на сервері.",
@@ -215,7 +242,6 @@ OC.L10N.register(
     "Trace" : "Трасування",
     "Security warning" : "Попередження безпеки",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог даних і ваші файли можливо доступні з інтернету, тому що  .htaccess файл не працює.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Для отримання інформації, як правильно налаштувати сервер, див. <a href=\"%s\" target=\"_blank\">документацію</a>.",
     "Create an <strong>admin account</strong>" : "Створити <strong>обліковий запис адміністратора</strong>",
     "Username" : "Ім'я користувача",
     "Storage & database" : "Сховище і база даних",
@@ -243,11 +269,13 @@ OC.L10N.register(
     "Search" : "Пошук",
     "Server side authentication failed!" : "Невдала аутентифікація з сервером!",
     "Please contact your administrator." : "Будь ласка, зверніться до вашого Адміністратора.",
-    "An internal error occured." : "Виникла внутрішня помилка.",
+    "An internal error occurred." : "Виникла внутрішня помилка.",
     "Please try again or contact your administrator." : "Будь ласка, спробуйте ще раз або зверніться до адміністратора.",
+    "Username or email" : "Ім’я користувача або електронна пошта",
     "Log in" : "Увійти",
     "Wrong password. Reset it?" : "Невірний пароль. Скинути його?",
     "Wrong password." : "Невірний пароль.",
+    "Stay logged in" : "Залишатись в системі",
     "Alternative Logins" : "Альтернативні імена користувача",
     "Use the following link to reset your password: {link}" : "Використовуйте наступне посилання для скидання пароля: {link}",
     "New password" : "Новий пароль",
@@ -257,6 +285,8 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Це означає, що тільки адміністратори можуть використовувати сервер.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Зверніться до вашого системного адміністратора якщо це повідомлення не зникає або з'являється несподівано.",
     "Thank you for your patience." : "Дякуємо за ваше терпіння.",
+    "Two-step verification" : "Дворівнева перевірка",
+    "An error occured while verifying the token" : "При верифікації токена виникла помилка",
     "You are accessing the server from an untrusted domain." : "Ви намагаєтеся отримати доступ до сервера з непідтвердженого домену.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Залежно від конфігурації Ви як адміністратор можете додати цей домен у список довірених, використовуйте кнопку нижче.",
     "Add \"%s\" as trusted domain" : "Додати \"%s\" як довірений домен",
@@ -268,6 +298,10 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продовженням переконайтеся, що ви зробили резервну копію бази даних, каталогу конфігурації та каталогу з даними.",
     "Start update" : "Почати оновлення",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Щоб уникнути затримок у великих встановленнях, ви можете виконати наступну команду в каталозі встановлення:",
+    "Detailed logs" : "Деталізований журнал",
+    "Update needed" : "Оновлення необхідно",
+    "Please use the command line updater because you have a big instance." : "Просимо запустити процес оновлення з командного рядка, оскільки ви маєте багато даних.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "За допомогою зверніться до <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документації</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Цей %s знаходиться в режимі технічного обслуговування, яке може зайняти деякий час.",
     "This page will refresh itself when the %s instance is available again." : "Ця сторінка автоматично перезавантажиться коли екземпляр %s стане знову доступний."
 },
