@@ -17,14 +17,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Berikut adalah platform yang didukung: %s",
     "ownCloud %s or higher is required." : "Diperlukan ownCloud %s atau yang lebih tinggi.",
     "ownCloud %s or lower is required." : "ownCloud %s atau yang lebih rendah diperlukan.",
-    "Help" : "Bantuan",
-    "Personal" : "Pribadi",
-    "Users" : "Pengguna",
-    "Admin" : "Admin",
-    "Recommended" : "Direkomendasikan",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Aplikasi \"%s\" tidak dapat diinstal karena tidak kompatibel dengan ownCloud versi ini.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikasi \"%s\" tidak dapat diinstal karena dependensi berikut belum terpenuhi: %s",
-    "No app name specified" : "Tidak ada nama apl yang ditentukan",
     "Unknown filetype" : "Tipe berkas tak dikenal",
     "Invalid image" : "Gambar tidak sah",
     "today" : "hari ini",
@@ -37,7 +29,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n jam yang lalu"],
     "_%n minute ago_::_%n minutes ago_" : ["%n menit yang lalu"],
     "seconds ago" : "beberapa detik yang lalu",
-    "web services under your control" : "layanan web dalam kendali anda",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul dengan id: %s tidak ada. Mohon aktifkan modul tersebut di pengaturan aplikasi Anda atau hubungi administrator.",
     "Empty filename is not allowed" : "Nama berkas kosong tidak diperbolehkan",
     "Dot files are not allowed" : "Berkas titik tidak diperbolehkan",
@@ -45,8 +36,6 @@ OC.L10N.register(
     "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
     "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
     "File name is too long" : "Nama berkas terlalu panjang",
-    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
-    "Can't read file" : "Tidak dapat membaca berkas",
     "App directory already exists" : "Direktori Apl sudah ada",
     "Can't create app folder. Please fix permissions. %s" : "Tidak dapat membuat folder apl. Silakan perbaiki perizinan. %s",
     "Archive does not contain a directory named %s" : "Arsip tidak berisi direktori yang bernama %s",
@@ -59,11 +48,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Apl tidak dapat diinstal karena terdapat kode yang tidak diizinkan didalam Apl",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Apl tidak dapat diinstal karena tidak kompatibel dengan versi ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Apl tidak dapat diinstal karena mengandung tag <shipped>true</shipped> yang tidak diizinkan untuk apl yang bukan bawaan.",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Apl tidak dapat diinstal karena versi di info.xml/versi tidak sama dengan versi yang dilansir dari toko apl",
-    "Application is not enabled" : "Aplikasi tidak diaktifkan",
-    "Authentication error" : "Galat saat otentikasi",
-    "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
-    "Unknown user" : "Pengguna tidak dikenal",
     "%s enter the database username." : "%s masukkan nama pengguna basis data.",
     "%s enter the database name." : "%s masukkan nama basis data.",
     "%s you may not use dots in the database name" : "%s anda tidak boleh menggunakan karakter titik pada nama basis data",
@@ -87,7 +71,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Gagal berbagi %s, karena backend tidak mengizinkan berbagi dengan tipe %i",
     "Sharing %s failed, because the file does not exist" : "Gagal membagikan %s, karena berkas tidak ada",
     "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Gagal membagikan %s, karena pengguna %s adalah pemilik item",
+    "Sharing %s failed, because you can not share with yourself" : "Berbagi %s gagal, karena Anda tidak dapat berbagi dengan diri sendiri",
     "Sharing %s failed, because the user %s does not exist" : "Gagal membagikan %s, karena pengguna %s tidak ada",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Gagal membagikan %s, karena pengguna %s bukan merupakan anggota dari grup yang %s ikuti",
     "Sharing %s failed, because this item is already shared with %s" : "Gagal membagkan %s, karena item ini sudah dibagikan dengan %s",
@@ -106,17 +90,31 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
     "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
-    "Sharing %s failed, because the user %s is the original sharer" : "Gagal berbagi %s. karena pengguna %s adalah yang membagikan pertama",
+    "Sharing failed, because the user %s is the original sharer" : "Berbagi gagal, karena pengguna %s adalah pembagi awal",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Gagal membagikan %s, karena izin melebihi izin yang diberikan untuk %s",
     "Sharing %s failed, because resharing is not allowed" : "Gagal berbagi %s, karena membagikan ulang tidak diizinkan",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Berbagi %s gagal, karena backend berbagi untuk %s tidak menemukan sumbernya",
     "Sharing %s failed, because the file could not be found in the file cache" : "Gagal berbagi %s, karena berkas tidak ditemukan di berkas cache",
     "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
     "Apps" : "Aplikasi",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Hanya karakter berikut yang diizinkan dalam nama pengguna: \"a-z\", \"A-Z\", \"0-9\", dan \"_.@-\"",
     "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
     "A valid password must be provided" : "Tuliskan sandi yang valid",
     "The username is already being used" : "Nama pengguna ini telah digunakan",
+    "Help" : "Bantuan",
+    "Personal" : "Pribadi",
+    "Users" : "Pengguna",
+    "Admin" : "Admin",
+    "Recommended" : "Direkomendasikan",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Aplikasi \"%s\" tidak dapat diinstal karena tidak kompatibel dengan ownCloud versi ini.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikasi \"%s\" tidak dapat diinstal karena dependensi berikut belum terpenuhi: %s",
+    "No app name specified" : "Tidak ada nama apl yang ditentukan",
+    "web services under your control" : "layanan web dalam kendali anda",
+    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
+    "Can't read file" : "Tidak dapat membaca berkas",
+    "Application is not enabled" : "Aplikasi tidak diaktifkan",
+    "Authentication error" : "Galat saat otentikasi",
+    "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
+    "Unknown user" : "Pengguna tidak dikenal",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Tidak ada driver (sqlite, mysql, or postgresql) yang terinstal.",
     "Microsoft Windows Platform is not supported" : "Platform Microsoft Windows tidak didukung",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Menjalankan server ownCloud pada platform Microsoft Windows tidak didukung. Kami menyarankan Anda untuk menggunakan server Linux di mesin virtual jika Anda tidak memiliki pilihan untuk bermigrasi server itu sendiri. Temukan paket Linux atau menggunakan images mesin virtual di <a href=\"%s\">%s</a>. Untuk bermigrasi dari instalasi yang sudah ada ke Linux, Anda dapat menemukan beberapa tips dan script migrasi di <a href=\"%s\">dokumentasi kami</a>.",
@@ -124,7 +122,6 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "Tidak dapat menulis kedalam direktori \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Hal ini biasanya dapat diperbaiki dengan %s memberikan akses tulis bagi situs web ke %s direktori apps atau menonaktifkan toko aplikasi didalam berkas config.",
     "Cannot create \"data\" directory (%s)" : "Tidak dapat membuat direktori (%s) \"data\"",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Hal ini biasanya dapat diperbaiki dengan <a href=\"%s\" target=\"_blank\">memberikan akses tulis bagi situs web ke direktori root</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Perizinan biasanya dapat diperbaiki dengan %s memberikan akses tulis bagi situs web ke %s direktori root.",
     "Setting locale to %s failed" : "Pengaturan lokal ke %s gagal",
     "Please install one of these locales on your system and restart your webserver." : "Mohon instal paling tidak satu lokal pada sistem Anda dan jalankan ulang server web.",
@@ -140,14 +137,13 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
     "PostgreSQL >= 9 required" : "Diperlukan PostgreSQL >= 9",
     "Please upgrade your database version" : "Mohon perbarui versi basis data Anda",
-    "Error occurred while checking PostgreSQL version" : "Terjadi kesalahan saat memeriksa versi PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Pastikan bahwa Anda memiliki PostgreSQL >= 9 atau periksa log untuk informasi lebih lanjut tentang kesalahan",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
     "Data directory (%s) is readable by other users" : "Direktori data (%s) dapat dibaca oleh pengguna lain",
     "Data directory (%s) must be an absolute path" : "Direktori Data (%s) harus berupa lokasi lengkap",
     "Check the value of \"datadirectory\" in your configuration" : "Periksa nilai \"datadirectory\" di konfigurasi Anda",
     "Data directory (%s) is invalid" : "Direktori data (%s) tidak sah",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Mohon periksa apakah direktori data berisi sebuah berkas \".ocdata\" di direktori induknya.",
-    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\".",
+    "Storage not available" : "Penyimpanan tidak tersedia"
 },
 "nplurals=1; plural=0;");
