@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "サンプル設定がコピーされてそのままです。このままではインストールが失敗し、サポート対象外になります。config.phpを変更する前にドキュメントを確認してください。",
     "PHP %s or higher is required." : "PHP %s 以上が必要です。",
     "PHP with a version lower than %s is required." : "%s 以前のバージョンのPHPが必要です。",
+    "%sbit or higher PHP required." : "%sbit 以上の新しいバージョンのPHPが必要です。",
     "Following databases are supported: %s" : "次のデータベースをサポートしています: %s",
     "The command line tool %s could not be found" : "コマンド '%s' は見つかりませんでした。",
     "The library %s is not available." : " %s ライブラリーが利用できません。",
@@ -17,14 +18,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "次のプラットフォームをサポートしています: %s",
     "ownCloud %s or higher is required." : "ownCloud %s 以上が必要です。",
     "ownCloud %s or lower is required." : "ownCloud %s 以下が必要です。",
-    "Help" : "ヘルプ",
-    "Personal" : "個人",
-    "Users" : "ユーザー",
-    "Admin" : "管理",
-    "Recommended" : "おすすめ",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : " \"%s\" アプリは、このバージョンのownCloudと互換性がない為、インストールできません。",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "次の依存関係が満たされないため、\"%s\" アプリをインストールできません：%s",
-    "No app name specified" : "アプリ名が未指定",
     "Unknown filetype" : "不明なファイルタイプ",
     "Invalid image" : "無効な画像",
     "today" : "今日",
@@ -37,7 +30,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n 時間前"],
     "_%n minute ago_::_%n minutes ago_" : ["%n 分前"],
     "seconds ago" : "数秒前",
-    "web services under your control" : "あなたが管理するウェブサービス",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "id: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
     "Empty filename is not allowed" : "空のファイル名は許可されていません",
     "Dot files are not allowed" : "ドットファイルは許可されていません",
@@ -45,8 +37,6 @@ OC.L10N.register(
     "File name is a reserved word" : "ファイル名が予約された単語です",
     "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
     "File name is too long" : "ファイル名が長すぎます",
-    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
-    "Can't read file" : "ファイルを読み込めません",
     "App directory already exists" : "アプリディレクトリはすでに存在します",
     "Can't create app folder. Please fix permissions. %s" : "アプリフォルダーを作成できませんでした。%s のパーミッションを修正してください。",
     "Archive does not contain a directory named %s" : "%s という名前のディレクトリは、アーカイブに含まれていません",
@@ -56,15 +46,13 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "\"%s\"タイプのアーカイブ形式は未サポート",
     "Failed to open archive when installing app" : "アプリをインストール中にアーカイブファイルを開けませんでした。",
     "App does not provide an info.xml file" : "アプリにinfo.xmlファイルが入っていません",
+    "App cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリがインストールできません。",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "署名が確認できませんでした｡このアプリの開発者へ連絡し、管理画面を確認してください。",
     "App can't be installed because of not allowed code in the App" : "アプリで許可されないコードが入っているのが原因でアプリがインストールできません",
     "App can't be installed because it is not compatible with this version of ownCloud" : "アプリは、このバージョンのownCloudと互換性がないためインストールできません。",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "非shippedアプリには許可されない<shipped>true</shipped>タグが含まれているためにアプリをインストールできません。",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "info.xmlのバージョンがアプリストアのバージョンと合っていないため、アプリはインストールされません",
-    "Application is not enabled" : "アプリケーションは無効です",
-    "Authentication error" : "認証エラー",
-    "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
-    "Unknown user" : "不明なユーザー",
+    "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
     "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
     "%s enter the database name." : "%s のデータベース名を入力してください。",
     "%s you may not use dots in the database name" : "%s ではデータベース名にドットを利用できないかもしれません。",
@@ -114,6 +102,8 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s の共有に失敗しました。%s のバックエンド共有に必要なソースが見つかりませんでした。",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s の共有に失敗しました。ファイルキャッシュにファイルがありませんでした。",
     "Cannot increase permissions of %s" : "%s　の権限を強化できません",
+    "Files can't be shared with delete permissions" : "削除権限つきでファイルを共有できません。",
+    "Files can't be shared with create permissions" : "作成権限つきでファイルを共有できません。",
     "Expiration date is in the past" : "有効期限が切れています",
     "Cannot set expiration date more than %s days in the future" : "有効期限を%s日以降に設定できません。",
     "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
@@ -123,6 +113,24 @@ OC.L10N.register(
     "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
     "A valid password must be provided" : "有効なパスワードを指定する必要があります",
     "The username is already being used" : "ユーザー名はすでに使われています",
+    "Login canceled by app" : "アプリによりログインが中止されました",
+    "User disabled" : "ユーザーは無効です",
+    "Help" : "ヘルプ",
+    "Personal" : "個人",
+    "Users" : "ユーザー",
+    "Admin" : "管理",
+    "Recommended" : "おすすめ",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリ名 \"%s\"  がインストールできません。",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : " \"%s\" アプリは、このバージョンのownCloudと互換性がない為、インストールできません。",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "次の依存関係が満たされないため、\"%s\" アプリをインストールできません：%s",
+    "No app name specified" : "アプリ名が未指定",
+    "web services under your control" : "あなたが管理するウェブサービス",
+    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
+    "Can't read file" : "ファイルを読み込めません",
+    "Application is not enabled" : "アプリケーションは無効です",
+    "Authentication error" : "認証エラー",
+    "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
+    "Unknown user" : "不明なユーザー",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "データベースドライバー (sqlite, mysql, postgresql) がインストールされていません。",
     "Microsoft Windows Platform is not supported" : "Microsoft Windows サーバーはサポートしていません。",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Microsoft Windowsサーバー上での ownCloud の動作は、サポートされていません。現在のサーバーOSを変更することができないのであれば、仮想マシン上で Linuxサーバーを動かすことをお勧めします。仮想マシンイメージを配置するのと同じぐらい簡単にLinuxパッケージを<a href=\"%s\">%s</a>で見つけられます。現在稼働中の設定をLinuxに移行する 移行スクリプトと注意点をこちらの<a href=\"%s\">ドキュメント</a>で確認してください。",
@@ -130,7 +138,7 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "\"apps\" ディレクトリに書き込みができません",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "多くの場合、これは %s Webサーバーにappsディレクトリ %s への書き込み権限を与えるか、設定ファイルでアプリストアを無効化することで解決できます。",
     "Cannot create \"data\" directory (%s)" : "\"data\" ディレクトリ (%s) を作成できません",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "多くの場合、これは<a href=\"%s\" target=\"_blank\">Webサーバーにルートディレクトリへの書き込み権限を与える</a>ことで解決できます。",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "通常、<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">Webサーバーにルートディレクトリへの書き込み権限を与える</a>ことで解決できます。",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "多くの場合、パーミッションは %s Webサーバーにルートディレクトリ %s への書き込み権限を与えることで解決できます。",
     "Setting locale to %s failed" : "ロケールを %s に設定できませんでした",
     "Please install one of these locales on your system and restart your webserver." : "これらのロケールのうちいずれかをシステムにインストールし、Webサーバーを再起動してください。",
@@ -140,6 +148,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "php.ini 中の設定を調整するとownCloudはもう一度動作するでしょう。 ",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload の値は \"0\" であるべきですが、\"%s\" に設定されています",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "この問題を修正するには、php.ini ファイルの <code>mbstring.func_overload</code> を <code>0</code> に設定してください。",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "最低バージョン 2.7.0  のlibxml2 が必要です。現在 %s がインストールされています。",
+    "To fix this issue update your libxml2 version and restart your web server." : "この問題を解決するには、libxml2 を更新して、ウェブサーバーを再起動してください。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHPでインラインドキュメントブロックを取り除く設定になっています。これによりコアアプリで利用できないものがいくつかあります。",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "これは、Zend OPcacheやeAccelerator 等のキャッシュ/アクセラレーターが原因かもしれません。",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP モジュールはインストールされていますが、まだ一覧に表示されていますか？",
