@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração exemplo foi copiada. Isso pode desestabilizar sua instalação e não é suportado. Por favor, leia a documentação antes de realizar mudanças no config.php",
     "PHP %s or higher is required." : "É requerido PHP %s ou superior.",
     "PHP with a version lower than %s is required." : "É requerida uma versão PHP mais antiga que a %s .",
+    "%sbit or higher PHP required." : "%sbit ou maior é requerido.",
     "Following databases are supported: %s" : "Following databases are supported: %s",
     "The command line tool %s could not be found" : "A ferramenta de linha de comando %s não pode ser encontrada",
     "The library %s is not available." : "A biblioteca %s não está disponível.",
@@ -17,14 +18,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
     "ownCloud %s or higher is required." : "É necessário um ownCloud %s ou superior.",
     "ownCloud %s or lower is required." : "É necessário um ownCloud %s ou inferior.",
-    "Help" : "Ajuda",
-    "Personal" : "Pessoal",
-    "Users" : "Usuários",
-    "Admin" : "Admin",
-    "Recommended" : "Recomendado",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "App \"%s\" não pode ser instalado porque não é compatível com esta versão do ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" não pode ser instalado porque as seguintes dependências não foram cumpridas: %s",
-    "No app name specified" : "O nome do aplicativo não foi especificado.",
     "Unknown filetype" : "Tipo de arquivo desconhecido",
     "Invalid image" : "Imagem inválida",
     "today" : "hoje",
@@ -37,7 +30,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["há %n hora atrás","há %n horas atrás"],
     "_%n minute ago_::_%n minutes ago_" : ["há %n minuto atrás","há %n minutos atrás"],
     "seconds ago" : "segundos atrás",
-    "web services under your control" : "serviços web sob seu controle",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Módulo com id: %s não existe. Ative-o em suas configurações de aplicativos ou contate o administrador.",
     "Empty filename is not allowed" : "Um nome de arquivo vazio não é permitido.",
     "Dot files are not allowed" : "Dot arquivos não são permitidos",
@@ -45,8 +37,6 @@ OC.L10N.register(
     "File name is a reserved word" : "O nome do arquivo é uma palavra reservada",
     "File name contains at least one invalid character" : "O nome do arquivo contém pelo menos um caractere inválido",
     "File name is too long" : "O nome do arquivo é muito longo",
-    "File is currently busy, please try again later" : "O arquivo está ocupado, tente novamente mais tarde",
-    "Can't read file" : "Não é possível ler arquivo",
     "App directory already exists" : "Diretório App  já existe",
     "Can't create app folder. Please fix permissions. %s" : "Não é possível criar pasta app. Corrija as permissões. %s",
     "Archive does not contain a directory named %s" : "O arquivo não contém um diretório chamado %s",
@@ -56,14 +46,13 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Arquivos do tipo %s não são suportados",
     "Failed to open archive when installing app" : "Falha para abrir o arquivo enquanto instalava o aplicativo",
     "App does not provide an info.xml file" : "O aplicativo não fornece um arquivo info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "O App não pode ser instalado porque o arquivo appinfo não pode ser lido.",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "A assinatura não pode ser verificada. Por favor entre em contato com o desenvolvedor do aplicativo e verificar sua tela de administração.",
     "App can't be installed because of not allowed code in the App" : "O aplicativo não pode ser instalado por causa do código não permitido no Aplivativo",
     "App can't be installed because it is not compatible with this version of ownCloud" : "O aplicativo não pode ser instalado porque não é compatível com esta versão do ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "O aplicativo não pode ser instalado porque ele contém a marca <shipped>verdadeiro</shipped> que não é permitido para aplicações não embarcadas",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "O aplicativo não pode ser instalado porque a versão em info.xml/versão não é a mesma que a versão relatada na App Store",
-    "Application is not enabled" : "Aplicação não está habilitada",
-    "Authentication error" : "Erro de autenticação",
-    "Token expired. Please reload page." : "Token expirou. Por favor recarregue a página.",
-    "Unknown user" : "Usuário desconhecido",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "O aplicativo não pode ser instalado porque a versão em info.xml não é o mesmo que a versão relatada na App Store",
+    "%s enter the database username and name." : "%s insira o nome de usuário e o nome do banco de dados.",
     "%s enter the database username." : "%s insira o nome de usuário do banco de dados.",
     "%s enter the database name." : "%s insira o nome do banco de dados.",
     "%s you may not use dots in the database name" : "%s você não pode usar pontos no nome do banco de dados",
@@ -87,7 +76,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "O compartilhamento %s falhou, porque o processo interno não permite ações de tipo %i",
     "Sharing %s failed, because the file does not exist" : "Compartilhamento %s falhou, porque o arquivo não existe",
     "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Compartilhamento %s falhou, porque o usuário %s é o proprietário do item",
+    "Sharing %s failed, because you can not share with yourself" : "O compartilhamento %s falhou, porque você não pode compartilhar com você mesmo",
     "Sharing %s failed, because the user %s does not exist" : "Compartilhamento %s falhou, porque o usuário %s não existe",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Compartilhamento %s falhou, porque o usuário %s não é membro de nenhum grupo que o usuário %s pertença",
     "Sharing %s failed, because this item is already shared with %s" : "Compartilhamento %s falhou, porque este ítem já está compartilhado com %s",
@@ -96,6 +85,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Compartilhamento %s falhou, porque  %s não é membro do grupo %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Você precisa fornecer uma senha para criar um link público, apenas links protegidos são permitidos",
     "Sharing %s failed, because sharing with links is not allowed" : "Compartilhamento %s falhou, porque compartilhamento com links não é permitido",
+    "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento associado com o mesmo usuário",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "O compartilhamento %s falhou, porque não foi possível encontrar %s, talvez o servidor esteja inacessível.",
     "Share type %s is not valid for %s" : "Tipo de compartilhamento %s não é válido para %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Definir permissões para %s falhou, porque as permissões excedem as permissões concedidas a %s",
@@ -106,17 +96,41 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Compartilhando backend %s deve implementar a interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Compartilhamento backend %s não encontrado",
     "Sharing backend for %s not found" : "Compartilhamento backend para %s não encontrado",
-    "Sharing %s failed, because the user %s is the original sharer" : "Compartilhando %s falhou, porque o usuário %s é o compartilhador original",
+    "Sharing failed, because the user %s is the original sharer" : "O compartilhamento falhou, porque o usuário %s é o compartilhador original",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Compartilhamento %s falhou, porque as permissões excedem as permissões concedidas a %s",
     "Sharing %s failed, because resharing is not allowed" : "Compartilhamento %s falhou, porque recompartilhamentos não são permitidos",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Compartilhamento %s falhou, porque a infra-estrutura de compartilhamento para %s não conseguiu encontrar a sua fonte",
     "Sharing %s failed, because the file could not be found in the file cache" : "Compartilhamento %s falhou, porque o arquivo não pôde ser encontrado no cache de arquivos",
+    "Cannot increase permissions of %s" : "Não é possível aumentar as permissões de %s",
+    "Files can't be shared with delete permissions" : "Os arquivos não podem ser compartilhadas com permissões de exclusão",
+    "Files can't be shared with create permissions" : "Os arquivos não podem ser compartilhados com permissões de criação",
+    "Expiration date is in the past" : "Data de validade está ultrapassada",
+    "Cannot set expiration date more than %s days in the future" : "Não é possível definir a data de validade mais de %s dias no futuro",
     "Could not find category \"%s\"" : "Impossível localizar categoria \"%s\"",
     "Apps" : "Aplicações",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Somente os seguintes caracteres são permitidos no nome do usuário: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
     "A valid username must be provided" : "Forneça um nome de usuário válido",
+    "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
     "A valid password must be provided" : "Forneça uma senha válida",
     "The username is already being used" : "Este nome de usuário já está sendo usado",
+    "Login canceled by app" : "Login cancelado pelo aplicativo",
+    "User disabled" : "Usuário desativado",
+    "Help" : "Ajuda",
+    "Personal" : "Pessoal",
+    "Users" : "Usuários",
+    "Admin" : "Admin",
+    "Recommended" : "Recomendado",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "O App \"%s\" não pode ser instalado porque o arquivo appinfo não pode ser lido.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "App \"%s\" não pode ser instalado porque não é compatível com esta versão do ownCloud.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" não pode ser instalado porque as seguintes dependências não foram cumpridas: %s",
+    "No app name specified" : "O nome do aplicativo não foi especificado.",
+    "web services under your control" : "serviços web sob seu controle",
+    "File is currently busy, please try again later" : "O arquivo está ocupado, tente novamente mais tarde",
+    "Can't read file" : "Não é possível ler arquivo",
+    "Application is not enabled" : "Aplicação não está habilitada",
+    "Authentication error" : "Erro de autenticação",
+    "Token expired. Please reload page." : "Token expirou. Por favor recarregue a página.",
+    "Unknown user" : "Usuário desconhecido",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhum driver  de banco de dados (sqlite, mysql, or postgresql) instalado.",
     "Microsoft Windows Platform is not supported" : "Plataforma Microsoft Windows não é suportada",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Não é suportado execução do ownCloud Server na plataforma Microsoft Windows. Nós sugerimos que você use um servidor Linux em uma máquina virtual, se você não tem opção para migrar o próprio servidor. Encontre pacotes Linux, bem como imagens de máquinas virtuais fáceis de implantar  em <a href=\"%s\">%s</a>. Para migrar as instalações existentes para Linux pode encontrar algumas dicas e um script de migração em <a href=\"%s\">nossa documentação</a>.",
@@ -124,7 +138,7 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "Não é possível gravar no diretório \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Isto pode ser corrigido dando ao webserver permissão de escrita %sgiving para o diretório apps directory%s ou desabilitando o appstore no arquivo de configuração.",
     "Cannot create \"data\" directory (%s)" : "Não pode ser criado \"dados\" no diretório (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Isto pode ser corrigido por <a href=\"%s\" target=\"_blank\">dando ao webserver permissão de escrita ao diretório raiz</a>.",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Esta geralmente pode ser fixado por <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dando permissão de gravação ao diretório raiz do servidor</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Permissões podem ser corrigidas dando permissão de escita %sgiving ao webserver para o diretório raiz directory%s",
     "Setting locale to %s failed" : "Falha ao configurar localidade para %s",
     "Please install one of these locales on your system and restart your webserver." : "Por favor, defina uma dessas localizações em seu sistema e reinicie o seu servidor web.",
@@ -134,20 +148,25 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Ajustando esta configuração no php.ini irá fazer o ownCloud rodar novamente",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está definido para \"%s\" em vez do valor esperado \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corrigir esse problema defina <code>mbstring.func_overload</code> para <code>0</code> em seu php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "A libxml2 2.7.0 é a mínima versão requerida. Atualmente a versão %s está instalada.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Para corrigir este problema, atualize a versão da sua libxml2 e reinicie seu servidor web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está, aparentemente, configurado para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por uma cache/acelerador, como Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Módulos do PHP foram instalados, mas eles ainda estão listados como desaparecidos?",
     "Please ask your server administrator to restart the web server." : "Por favor, peça ao seu administrador do servidor para reiniciar o servidor web.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requirido",
     "Please upgrade your database version" : "Por favor, atualize sua versão do banco de dados",
-    "Error occurred while checking PostgreSQL version" : "Erro ao verificar a versão do PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Por favor, verifique se você tem PostgreSQL> = 9 ou verificar os logs para obter mais informações sobre o erro",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor, altere as permissões para 0770 para que o diretório não possa ser listado por outros usuários.",
     "Data directory (%s) is readable by other users" : "Diretório de dados (%s) pode ser lido por outros usuários",
     "Data directory (%s) must be an absolute path" : "Diretório de dados (%s) deve ser um caminho absoluto",
     "Check the value of \"datadirectory\" in your configuration" : "Verifique o valor do \"diretóriodedados\" na sua configuração",
     "Data directory (%s) is invalid" : "Diretório de dados (%s) é inválido",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Por favor, verifique se o diretório de dados contém um arquivo \".ocdata\" em sua raiz.",
-    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter tipo de bloqueio %d em \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter tipo de bloqueio %d em \"%s\".",
+    "Storage unauthorized. %s" : "Armazenamento não autorizado. %s",
+    "Storage incomplete configuration. %s" : "Incompleta configuração de armazenamento. %s",
+    "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
+    "Storage not available" : "Armazanamento não disponível",
+    "Storage connection timeout. %s" : "Tempo limite de conexão de armazenamento. %s"
 },
 "nplurals=2; plural=(n > 1);");
