@@ -8,7 +8,8 @@ OC.L10N.register(
     "Sample configuration detected" : "ตรวจพบการกำหนดค่าตัวอย่าง",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "ตรวจพบว่าการกำหนดค่าตัวอย่างที่ถูกคัดลอก นี้สามารถทำลายการติดตั้งของคุณและไม่ได้รับการสนับสนุน โปรดอ่านเอกสารก่อนที่จะดำเนินการเปลี่ยนแปลงใน config.php",
     "PHP %s or higher is required." : "จำเป็นต้องมี PHP รุ่น %s หรือที่สูงกว่า ",
-    "PHP with a version lower than %s is required." : "PHP จะต้องมีรุ่นที่ต่ำกว่า %s",
+    "PHP with a version lower than %s is required." : "รุ่น PHP ของคุณต่ำกว่า %s",
+    "%sbit or higher PHP required." : "%sบิต หรือ PHP จะต้องเป็นรุ่นสูงกว่าที่กำหนด",
     "Following databases are supported: %s" : "ฐานข้อมูลต่อไปนี้ได้รับการสนับสนุน: %s",
     "The command line tool %s could not be found" : "ไม่พบเครื่องมือบรรทัดคำสั่ง %s ",
     "The library %s is not available." : "ไลบรารี %s ไม่สามารถใช้ได้",
@@ -17,14 +18,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "แพลตฟอร์มต่อไปนี้ได้รับการสนับสนุน: %s",
     "ownCloud %s or higher is required." : "จำเป็นต้องมี ownCloud รุ่น %s หรือรุ่นที่สูงกว่า",
     "ownCloud %s or lower is required." : "ต้องการ ownCloud %s หรือรุ่นที่ต่ำกว่า",
-    "Help" : "ช่วยเหลือ",
-    "Personal" : "ส่วนตัว",
-    "Users" : "ผู้ใช้งาน",
-    "Admin" : "ผู้ดูแล",
-    "Recommended" : "แนะนำ",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "แอพฯ \"%s\" ไม่สามารถติดตั้งได้เพราะเข้ากันไม่ได้กับรุ่นของ ownCloud นี้",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "แอพฯ \"%s\" ไม่สามารถติดตั้งเพราะไม่ได้ปฏิบัติตามการอ้างอิงต่อไปนี้: %s",
-    "No app name specified" : "ไม่ได้ระบุชื่อแอพพลิเคชัน",
     "Unknown filetype" : "ไม่รู้จักชนิดของไฟล์",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
     "today" : "วันนี้",
@@ -37,7 +30,6 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n ชั่วโมงที่ผ่านมา"],
     "_%n minute ago_::_%n minutes ago_" : ["%n นาทีที่ผ่านมา"],
     "seconds ago" : "วินาที ก่อนหน้านี้",
-    "web services under your control" : "เว็บเซอร์วิสที่คุณควบคุมการใช้งานได้",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "โมดูลที่มีไอดี: %s ไม่มีอยู่ กรุณาเปิดใช้งานได้ในการตั้งค่าแอพพลิเคชันของคุณหรือติดต่อผู้ดูแลระบบ",
     "Empty filename is not allowed" : "ชื่อไฟล์ห้ามว่างเปล่า",
     "Dot files are not allowed" : "ชื่อไฟล์ห้ามมีจุด",
@@ -45,8 +37,6 @@ OC.L10N.register(
     "File name is a reserved word" : "ชื่อแฟ้มเป็นคำสงวน",
     "File name contains at least one invalid character" : "ชื่อแฟ้มมีหนึ่งตัวอักษรที่ไม่ถูกต้อง",
     "File name is too long" : "ชื่อแฟ้มยาวเกินไป",
-    "File is currently busy, please try again later" : "ขณะนี้ไฟล์กำลังใช้งานอยู่ โปรดลองอีกครั้งในภายหลัง",
-    "Can't read file" : "ไม่สามารถอ่านไฟล์",
     "App directory already exists" : "มีไดเรกทอรีแอพฯอยู่แล้ว",
     "Can't create app folder. Please fix permissions. %s" : "ไม่สามารถสร้างโฟลเดอร์แอพพลิเคชัน โปรดแก้ไขการอนุญาต: %s",
     "Archive does not contain a directory named %s" : "เอกสารไม่สามารถประกอบด้วยไดเรกทอรีชื่อ %s",
@@ -56,17 +46,16 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "ประเภทข้อมูลที่เก็บของ %s ไม่ได้รับการสนับสนุน",
     "Failed to open archive when installing app" : "ไม่สามารถเปิดที่เก็บข้อมูลเมื่อกำลังติดตั้งแอพพลิเคชั่น",
     "App does not provide an info.xml file" : "แอพฯ ไม่ได้ระบุไฟล์ info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "ไม่สามารถติดตั้งแอพฯเพราะไม่สามารถอ่านไฟล์ AppInfo ได้",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "ไม่สามารถตรวจสอบลายเซ็น โปรดติดต่อนักพัฒนาแอพพลิเคชันและตรวจสอบหน้าจอแผงควบคุมระบบของคุณ",
     "App can't be installed because of not allowed code in the App" : "ไม่สามารถติดตั้งแอพพลิเคชันเพราะไม่ได้อนุญาตรหัสในแอพพลิเคชัน",
     "App can't be installed because it is not compatible with this version of ownCloud" : "ไม่สามารถติดตั้งแอพพลิเคชันเพราะมันเข้ากันไม่ได้กับรุ่นของ ownCloud นี้",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "ไม่สามารถติดตั้งแอพพลิเคชันเพราะมันมี <shipped>จริง</shipped> แท็กที่ไม่ได้รับอนุญาต",
-    "Application is not enabled" : "แอพพลิเคชั่นดังกล่าวยังไม่ได้เปิดใช้งาน",
-    "Authentication error" : "เกิดข้อผิดพลาดในสิทธิ์การเข้าใช้งาน",
-    "Token expired. Please reload page." : "รหัสยืนยันความถูกต้องหมดอายุแล้ว กรุณาโหลดหน้าเว็บใหม่อีกครั้ง",
-    "Unknown user" : "ไม่รู้จักผู้ใช้",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "ไม่สามารถติดตั้งแอพฯ เพราะว่ารุ่นของ info.xml ไม่ตรงกับรุ่นที่ระบุไว้จากแอพสโตร์",
+    "%s enter the database username and name." : "%s ป้อนชื่อผู้ใช้ฐานข้อมูล และชื่อ",
     "%s enter the database username." : "%s ใส่ชื่อผู้ใช้ฐานข้อมูล",
     "%s enter the database name." : "%s ใส่ชื่อฐานข้อมูล",
-    "%s you may not use dots in the database name" : "%s  บางที่คุณไม่ควรใช้จุดในชื่อฐานข้อมูล",
+    "%s you may not use dots in the database name" : "%s บางที่คุณไม่ควรมีจุดในชื่อฐานข้อมูล",
     "Oracle connection could not be established" : "ไม่สามารถสร้างการเชื่อมต่อกับ Oracle ",
     "Oracle username and/or password not valid" : "Oracle ชื่อผู้ใช้ และ/หรือ รหัสผ่านไม่ถูกต้อง",
     "DB Error: \"%s\"" : "ข้อผิดพลาดในฐานข้อมูล: \"%s\"",
@@ -113,6 +102,8 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "การแชร์ %s ล้มเหลวเพราะการแชร์แบ็กเอนด์สำหรับ %s ไม่สามารถหาแหล่งที่มา",
     "Sharing %s failed, because the file could not be found in the file cache" : "การแชร์ %s ล้มเหลวเพราะไม่พบไฟล์ในแคชไฟล์",
     "Cannot increase permissions of %s" : "ไม่สามารถเพิ่มสิทธิ์ของ %s",
+    "Files can't be shared with delete permissions" : "ไม่สามารถแชร์ไฟล์และลบสิทธิ์",
+    "Files can't be shared with create permissions" : "ไม่สามารถแชร์ไฟล์และสร้างสิทธิ์",
     "Expiration date is in the past" : "วันหมดอายุอยู่ในอดีตที่ผ่านมา",
     "Cannot set expiration date more than %s days in the future" : "ไม่สามารถกำหนดวันหมดอายุให้มากกว่า %s วันในอนาคต",
     "Could not find category \"%s\"" : "ไม่พบหมวดหมู่ \"%s\"",
@@ -121,6 +112,24 @@ OC.L10N.register(
     "A valid username must be provided" : "จะต้องระบุชื่อผู้ใช้ที่ถูกต้อง",
     "A valid password must be provided" : "รหัสผ่านที่ถูกต้องจะต้องให้",
     "The username is already being used" : "มีคนใช้ชื่อผู้ใช้นี้ไปแล้ว",
+    "Login canceled by app" : "การเข้าสู่ระบบถูกยกเลิกโดยแอพฯ",
+    "User disabled" : "ปิดการใช้งานผู้ใช้แล้ว",
+    "Help" : "ช่วยเหลือ",
+    "Personal" : "ส่วนตัว",
+    "Users" : "ผู้ใช้งาน",
+    "Admin" : "ผู้ดูแล",
+    "Recommended" : "แนะนำ",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "แอพฯ \"%s\" ไม่สามารถติดตั้งได้เพราะไฟล์ appInfo ไม่สามารถอ่านได้",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "ไม่สามารถติดตั้งแอพฯ \"%s\" เพราะมันเข้ากันไม่ได้กับรุ่นของ ownCloud นี้",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "แอพฯ \"%s\" ไม่สามารถติดตั้งเพราะไม่ได้ปฏิบัติตามการอ้างอิงต่อไปนี้: %s",
+    "No app name specified" : "ไม่ได้ระบุชื่อแอพพลิเคชัน",
+    "web services under your control" : "translate by <a href=\"https://fb.me/kauw5164\">kauw5164</a>",
+    "File is currently busy, please try again later" : "ขณะนี้ไฟล์กำลังใช้งานอยู่ โปรดลองอีกครั้งในภายหลัง",
+    "Can't read file" : "ไม่สามารถอ่านไฟล์",
+    "Application is not enabled" : "แอพพลิเคชั่นดังกล่าวยังไม่ได้เปิดใช้งาน",
+    "Authentication error" : "เกิดข้อผิดพลาดในสิทธิ์การเข้าใช้งาน",
+    "Token expired. Please reload page." : "รหัสยืนยันความถูกต้องหมดอายุแล้ว กรุณาโหลดหน้าเว็บใหม่อีกครั้ง",
+    "Unknown user" : "ไม่รู้จักผู้ใช้",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "ไม่มีไดรเวอร์ฐานข้อมูล (sqlite, mysql, or postgresql) ที่ถูกติดตั้ง",
     "Microsoft Windows Platform is not supported" : "ไม่สนับสนุนแพลตฟอร์ม Microsoft Windows",
     "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "ไม่สนับสนุนการเรียกใช้เซิร์ฟเวอร์ ownCloud บนแพลตฟอร์ม Microsoft Windows เราขอแนะนำให้คุณใช้เซิร์ฟเวอร์ลินุกซ์ในเครื่องเสมือนถ้าคุณไม่มีตัวเลือกสำหรับการย้ายเซิร์ฟเวอร์เอง ค้นหาแพคเกจลินุกซ์เช่นเดียวกับที่ง่ายต่อการปรับใช้อิมเมจบนเครื่องเสมือน <a href=\"%s\">%s</a> สำหรับการย้ายการติดตั้งลินุกซ์ที่มีอยู่เพื่อให้คุณสามารถค้นหาเคล็ดลับและการย้ายในสคริปต์ <a href=\"%s\">เอกสารของเรา</a>",
@@ -128,7 +137,6 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory" : "ไม่สามารถเขียนลงในไดเรกทอรี \"แอพฯ\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "นี้มักจะสามารถแก้ไขโดย %s ให้เข้าถึงการเขียนเว็บเซิร์ฟเวอร์ไปยังไดเรกทอรีแอพพลิเคชัน %s หรือปิดการใช้ AppStore ในไฟล์ config",
     "Cannot create \"data\" directory (%s)" : "ไม่สามารถสร้าง \"data\" ไดเรกทอรี (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "นี้มักจะสามารถแก้ไขโดย <a href=\"%s\" target=\"_blank\">ให้เข้าถึงการเขียนเว็บเซิร์ฟเวอร์ไปยังไดเรกทอรีราก</a>",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "สิทธิ์จะสามารถได้รับการแก้ไขโดย %s ให้เข้าถึงการเขียนเว็บเซิร์ฟเวอร์ไปยังไดเรกทอรีราก %s",
     "Setting locale to %s failed" : "ตั้งค่าต้นทาง %s ล้มเหลว",
     "Please install one of these locales on your system and restart your webserver." : "กรุณาติดตั้งหนึ่งในต้นทางเหล่านี้บนระบบของคุณและเริ่มต้นเว็บเซิร์ฟเวอร์ของคุณ",
@@ -138,6 +146,7 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "การปรับตั้งค่าใน php.ini นี้ ownCloud จะทำงานอีกครั้ง",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload ถูกตั้งเป็น \"%s\" แทนที่จะเป็น \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "หากต้องการแก้ไขปัญหานี้กรุณาแก้ <code>mbstring.func_overload</code> เป็น <code>0</code> ในไฟล์ php.ini ของคุณ",
+    "To fix this issue update your libxml2 version and restart your web server." : "เพื่อแก้ไขปัญหานี้ กรุณาอัพเดทรุ่นของ libxml2 และรีสตาร์ทเว็บเซิร์ฟเวอร์ของคุณ",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "เห็นได้ชัดว่า PHP มีการตั้งค่าเพื่อดึงบล็อกเอกสารแบบอินไลน์ ซึ่งจะทำให้แอพพลิเคชันไม่สามารถเข้าถึงได้",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "นี้อาจเกิดจาก cache/accelerator อย่างเช่น Zend OPcache หรือ eAccelerator",
     "PHP modules have been installed, but they are still listed as missing?" : "โมดูล PHP ได้รับการติดตั้ง แต่พวกเขาไม่ได้ระบุไว้หรือมันอาจหายไป?",
