@@ -1,10 +1,6 @@
 OC.L10N.register(
     "lib",
     {
-    "Help" : "مدد",
-    "Personal" : "ذاتی",
-    "Users" : "یوزرز",
-    "Admin" : "ایڈمن",
     "Unknown filetype" : "غیر معرروف قسم کی فائل",
     "Invalid image" : "غلط تصویر",
     "today" : "آج",
@@ -12,7 +8,11 @@ OC.L10N.register(
     "last month" : "پچھلے مہنیے",
     "last year" : "پچھلے سال",
     "seconds ago" : "سیکنڈز پہلے",
-    "web services under your control" : "آپ کے اختیار میں ویب سروسیز",
-    "Apps" : "ایپز"
+    "Apps" : "ایپز",
+    "Help" : "مدد",
+    "Personal" : "ذاتی",
+    "Users" : "یوزرز",
+    "Admin" : "ایڈمن",
+    "web services under your control" : "آپ کے اختیار میں ویب سروسیز"
 },
 "nplurals=2; plural=(n != 1);");
