@@ -1,24 +1,24 @@
 OC.L10N.register(
     "settings",
     {
-    "Sharing" : "ভাগাভাগিরত",
-    "External Storage" : "বাহ্যিক সংরক্ষণাগার",
-    "Couldn't remove app." : "অ্যাপ অপসারণ করা গেলনা",
-    "Language changed" : "ভাষা পরিবর্তন করা হয়েছে",
-    "Invalid request" : "অনুরোধটি সঠিক নয়",
-    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
-    "Admins can't remove themself from the admin group" : "প্রশাসকবৃন্দ তাদেরকে প্রশাসক গোষ্ঠী থেকে মুছে ফেলতে পারবেন না",
-    "Unable to add user to group %s" : " %s গোষ্ঠীতে ব্যবহারকারী যোগ করা সম্ভব হলো না ",
-    "Unable to remove user from group %s" : "%s গোষ্ঠী থেকে ব্যবহারকারীকে অপসারণ করা সম্ভব হলো না",
-    "Couldn't update app." : "অ্যাপ নবায়ন করা গেলনা।",
     "Wrong password" : "ভুল কুটশব্দ",
     "No user supplied" : "ব্যবহারকারী দেয়া হয়নি",
+    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
     "Enabled" : "কার্যকর",
     "Saved" : "সংরক্ষণ করা হলো",
     "test email settings" : "ইমেইল নিয়ামকসমূহ পরীক্ষা করুন",
     "Email sent" : "ই-মেইল পাঠানো হয়েছে",
     "Email saved" : "ই-মেইল সংরক্ষন করা হয়েছে",
     "Your full name has been changed." : "আপনার পূর্ণ নাম পরিবর্তন করা হয়েছে।",
+    "Sharing" : "ভাগাভাগিরত",
+    "External Storage" : "বাহ্যিক সংরক্ষণাগার",
+    "Couldn't remove app." : "অ্যাপ অপসারণ করা গেলনা",
+    "Language changed" : "ভাষা পরিবর্তন করা হয়েছে",
+    "Invalid request" : "অনুরোধটি সঠিক নয়",
+    "Admins can't remove themself from the admin group" : "প্রশাসকবৃন্দ তাদেরকে প্রশাসক গোষ্ঠী থেকে মুছে ফেলতে পারবেন না",
+    "Unable to add user to group %s" : " %s গোষ্ঠীতে ব্যবহারকারী যোগ করা সম্ভব হলো না ",
+    "Unable to remove user from group %s" : "%s গোষ্ঠী থেকে ব্যবহারকারীকে অপসারণ করা সম্ভব হলো না",
+    "Couldn't update app." : "অ্যাপ নবায়ন করা গেলনা।",
     "All" : "সবাই",
     "Error while disabling app" : "অ্যাপ অকার্যকর করতে সমস্যা দেখা দিয়েছে  ",
     "Disable" : "নিষ্ক্রিয়",
@@ -34,6 +34,7 @@ OC.L10N.register(
     "undo" : "ক্রিয়া প্রত্যাহার",
     "never" : "কখনোই নয়",
     "__language_name__" : "__language_name__",
+    "Unlimited" : "অসীম",
     "None" : "কোনটিই নয়",
     "Login" : "প্রবেশ",
     "Expire after " : "এরপর মেয়াদোত্তীর্ণ হও",
@@ -61,16 +62,17 @@ OC.L10N.register(
     "Change password" : "কূটশব্দ পরিবর্তন করুন",
     "Language" : "ভাষা",
     "Help translate" : "অনুবাদ করতে সহায়তা করুন",
+    "Name" : "নাম",
+    "Username" : "ব্যবহারকারী",
+    "Done" : "শেষ হলো",
     "Get the apps to sync your files" : "আপনার ফাইলসমূহ সিংক করতে অ্যাপস নিন",
     "Show First Run Wizard again" : "প্রথমবার চালানোর যাদুকর পূনরায় প্রদর্শন কর",
-    "Username" : "ব্যবহারকারী",
     "Create" : "তৈরী কর",
     "Admin Recovery Password" : "প্রশাসক পূণরূদ্ধার কুটশব্দ",
     "Add Group" : "গ্রুপ যোগ কর",
     "Group" : "গোষ্ঠীসমূহ",
     "Everyone" : "সকলে",
     "Admins" : "প্রশাসন",
-    "Unlimited" : "অসীম",
     "Other" : "অন্যান্য",
     "Quota" : "কোটা",
     "Storage Location" : "সংরক্ষণাগার এর অবস্থান",
