@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Upozornění zabezpečení a nastavení",
-    "Sharing" : "Sdílení",
-    "Server-side encryption" : "Šifrování na serveru",
-    "External Storage" : "Externí úložiště",
-    "Cron" : "Cron",
-    "Email server" : "Emailový server",
-    "Log" : "Záznam",
-    "Tips & tricks" : "Tipy a triky",
-    "Updates" : "Aktualizace",
-    "Couldn't remove app." : "Nepodařilo se odebrat aplikaci.",
-    "Language changed" : "Jazyk byl změněn",
-    "Invalid request" : "Neplatný požadavek",
-    "Authentication error" : "Chyba přihlášení",
-    "Admins can't remove themself from the admin group" : "Správci se nemohou odebrat sami ze skupiny správců",
-    "Unable to add user to group %s" : "Nelze přidat uživatele do skupiny %s",
-    "Unable to remove user from group %s" : "Nelze odebrat uživatele ze skupiny %s",
-    "Couldn't update app." : "Nelze aktualizovat aplikaci.",
     "Wrong password" : "Nesprávné heslo",
     "No user supplied" : "Nebyl uveden uživatel",
+    "Authentication error" : "Chyba přihlášení",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Zadejte prosím administrátorské heslo pro obnovu, jinak budou všechna data ztracena",
     "Wrong admin recovery password. Please check the password and try again." : "Chybné administrátorské heslo pro obnovu. Překontrolujte správnost hesla a zkuste to znovu.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Úložiště nepodporuje změnu hesla, ale šifrovací klíč uživatele byl úspěšně aktualizován.",
@@ -38,7 +20,7 @@ OC.L10N.register(
     "Unable to delete group." : "Nelze smazat skupinu.",
     "log-level out of allowed range" : "úroveň logování z povoleného rozpětí",
     "Saved" : "Uloženo",
-    "test email settings" : "otestovat nastavení emailu",
+    "test email settings" : "Test nastavení emailu",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Při odesílání emailu nastala chyba. Překontrolujte prosím svá nastavení. (Error: %s)",
     "Email sent" : "Email odeslán",
     "You need to set your user email before being able to send test emails." : "Pro možnost odeslání zkušebních emailů musíte nejprve nastavit svou emailovou adresu.",
@@ -53,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "Email uložen",
     "Your full name has been changed." : "Vaše celé jméno bylo změněno.",
     "Unable to change full name" : "Nelze změnit celé jméno",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Upozornění zabezpečení a nastavení",
+    "Sharing" : "Sdílení",
+    "Server-side encryption" : "Šifrování na serveru",
+    "External Storage" : "Externí úložiště",
+    "Cron" : "Cron",
+    "Email server" : "Emailový server",
+    "Log" : "Záznam",
+    "Tips & tricks" : "Tipy a triky",
+    "Updates" : "Aktualizace",
+    "Couldn't remove app." : "Nepodařilo se odebrat aplikaci.",
+    "Language changed" : "Jazyk byl změněn",
+    "Invalid request" : "Neplatný požadavek",
+    "Admins can't remove themself from the admin group" : "Správci se nemohou odebrat sami ze skupiny správců",
+    "Unable to add user to group %s" : "Nelze přidat uživatele do skupiny %s",
+    "Unable to remove user from group %s" : "Nelze odebrat uživatele ze skupiny %s",
+    "Couldn't update app." : "Nelze aktualizovat aplikaci.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Jste si jisti, že chcete přidat \"{domain}\" mezi důvěryhodné domény?",
     "Add trusted domain" : "Přidat důvěryhodnou doménu",
     "Migration in progress. Please wait until the migration is finished" : "Migrace probíhá. Počkejte prosím než bude dokončena",
@@ -63,6 +63,7 @@ OC.L10N.register(
     "Experimental" : "Experimentální",
     "All" : "Vše",
     "No apps found for your version" : "Nebyly nalezeny aplikace pro vaši verzi",
+    "The app will be downloaded from the app store" : "Aplikace bude stažena z obchodu aplikací",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Oficiální aplikace jsou vyvíjeny komunitou ownCloud. Nabízejí funkce důležité pro ownCloud a jsou připraveny pro nasazení v produkčním prostředí.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Schválené aplikace jsou vyvíjeny důvěryhodnými vývojáři a prošly zběžným bezpečnostním prověřením. Jsou aktivně udržovány v repozitáři s otevřeným kódem a jejich správci je považují za stabilní pro občasné až normální použití.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "U této aplikace nebyla provedena kontrola na bezpečnostní problémy. Aplikace je nová nebo nestabilní. Instalujte pouze na vlastní nebezpečí.",
@@ -73,6 +74,9 @@ OC.L10N.register(
     "Disable" : "Zakázat",
     "Enable" : "Povolit",
     "Error while enabling app" : "Chyba při povolování aplikace",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Chyba: tuto aplikaci nelze zapnout, protože způsobuje nestabilitu serveru",
+    "Error: could not disable broken app" : "Chyba: nezdařilo se vypnout rozbitou aplikaci",
+    "Error while disabling broken app" : "Chyba při vypínání rozbité aplikace",
     "Updating...." : "Aktualizuji...",
     "Error while updating app" : "Chyba při aktualizaci aplikace",
     "Updated" : "Aktualizováno",
@@ -81,7 +85,11 @@ OC.L10N.register(
     "Uninstall" : "Odinstalovat",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikace byla povolena ale je třeba ji aktualizovat. Za 5 sekund budete přesměrování na stránku pro aktualizaci.",
     "App update" : "Aktualizace aplikace",
-    "No apps found for \"{query}\"" : "Nebyly nalezeny žádné aplikace pro \"{query}\"",
+    "No apps found for {query}" : "Nebyly nalezeny žádné aplikace pro {query}",
+    "Disconnect" : "Odpojit",
+    "Error while loading browser sessions and device tokens" : "Chyba při načítání sezení prohlížeče a tokenů přístroje",
+    "Error while creating device token" : "Chyba při vytváření tokenů přístroje",
+    "Error while deleting the token" : "Chyba při mazání tokenu",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Došlo k chybě. Nahrajte prosím ASCII-kódovaný PEM certifikát.",
     "Valid until {date}" : "Platný do {date}",
     "Delete" : "Smazat",
@@ -108,7 +116,10 @@ OC.L10N.register(
     "A valid password must be provided" : "Musíte zadat platné heslo",
     "A valid email must be provided" : "Musíte zadat platný email",
     "__language_name__" : "Česky",
+    "Unlimited" : "Neomezeně",
     "Personal info" : "Osobní informace",
+    "Sessions" : "Sezení",
+    "App passwords" : "Hesla aplikací",
     "Sync clients" : "Synchronizační klienti",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Vše (fatální problémy, chyby, varování, informační, ladící)",
     "Info, warnings, errors and fatal issues" : "Informace, varování, chyby a fatální problémy",
@@ -122,32 +133,34 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php není nejspíše správně nastaveno pro dotazování na proměnné hodnoty systému. Test s getenv(\"PATH\") vrací pouze prázdnou odpověď.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Zkontrolujte prosím konfiguraci php podle <a target=\"_blank\" href=\"%s\">instalační dokumentace a php konfiguraci na serveru, hlavně při použití php-fpm.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Zkontrolujte prosím konfiguraci php podle <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">instalační dokumentace ↗</a>, hlavně při použití php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurace je nastavena pouze pro čtení. Toto znemožňuje některá nastavení přes webové rozhraní. Dále musí být pro každou změnu povolen zápis do konfiguračního souboru ručně.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je patrně nastaveno tak, aby odstraňovalo bloky komentářů. Toto bude mít za následek nedostupnost množství hlavních aplikací.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaše databáze neběží s úrovní izolace transakcí \"READ COMMITED\". Toto může způsobit problémy při paralelním spouštění více akcí současně.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Server běží v prostředí Microsoft Windows. Pro optimální uživatelské pohodlí doporučujeme přejít na Linux.",
     "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Je nainstalován %1$s nižší verze než %2$s, z důvodu lepší stability a výkonu doporučujeme aktualizovat na novější verzi %1$s.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Schází PHP modul 'fileinfo'. Doporučujeme jej povolit pro nejlepší výsledky detekce typů MIME.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transakční uzamykání souborů je vypnuto, což může vést k problémům s \"race\" podmínkami. Pro zabránění těmto problémům povolte 'filelocking.enabled' v souboru config.php. Více informací lze nalézt v <a target=\"_blank\" href=\"%s\">dokumentaci ↗</a>.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transakční uzamykání souborů je vypnuto, což může vést k problémům s \"race\" podmínkami. Pro zabránění těmto problémům povolte 'filelocking.enabled' v souboru config.php. Více informací lze nalézt v <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaci ↗</a>.",
     "System locale can not be set to a one which supports UTF-8." : "Není možné nastavit znakovou sadu, která podporuje UTF-8.",
     "This means that there might be problems with certain characters in file names." : "To znamená, že se mohou vyskytnout problémy s určitými znaky v názvech souborů.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Velmi doporučujeme nainstalovat požadované balíčky do systému, pro podporu jednoho z následujících národních prostředí: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Instalace mimo kořenový adresář domény a používání systémového příkazu cron může způsobit problém s generováním správné URL. Pro zabránění těmto chybám nastavte prosím správnou cestu ve svém config.php souboru v hodnotě \"overwrite.cli.url\" (Je doporučena tato: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Nebylo možné spustit službu cron v CLI. Došlo k následujícím technickým chybám:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Ověřte znovu prosím informace z <a target=\"_blank\" href=\"%s\">instalační příručky ↗</a> a zkontrolujte <a href=\"#log-section\">log</a> na výskyt chyb a varování.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Prosím překontrolujte <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">instalační pokyny ↗</a> a zkontrolujte jakékoliv chyby a varování v <a href=\"#log-section\">logu</a>.",
     "All checks passed." : "Všechny testy byly úspěšné.",
     "Open documentation" : "Otevřít dokumentaci",
     "Allow apps to use the Share API" : "Povolit aplikacím používat API sdílení",
     "Allow users to share via link" : "Povolit uživatelům sdílení pomocí odkazů",
-    "Enforce password protection" : "Vynutit ochranu heslem",
     "Allow public uploads" : "Povolit veřejné nahrávání souborů",
-    "Allow users to send mail notification for shared files" : "Povolit uživatelům odesílat emailová upozornění pro sdílené soubory",
+    "Enforce password protection" : "Vynutit ochranu heslem",
     "Set default expiration date" : "Nastavit výchozí datum vypršení platnosti",
+    "Allow users to send mail notification for shared files" : "Povolit uživatelům odesílat emailová upozornění pro sdílené soubory",
     "Expire after " : "Vyprší po",
     "days" : "dnech",
     "Enforce expiration date" : "Vynutit datum vypršení",
     "Allow resharing" : "Povolit znovu-sdílení",
+    "Allow sharing with groups" : "Povolit sdílení se skupinami",
     "Restrict users to only share with users in their groups" : "Povolit sdílení pouze mezi uživateli v rámci skupiny",
     "Allow users to send mail notification for shared files to other users" : "Povolit uživatelům odesílat emailová upozornění na sdílené soubory ostatním uživatelům",
     "Exclude groups from sharing" : "Vyjmout skupiny ze sdílení",
@@ -185,7 +198,7 @@ OC.L10N.register(
     "SMTP Username" : "SMTP uživatelské jméno ",
     "SMTP Password" : "SMTP heslo",
     "Store credentials" : "Ukládat přihlašovací údaje",
-    "Test email settings" : "Otestovat nastavení emailu",
+    "Test email settings" : "Test nastavení emailu",
     "Send email" : "Odeslat email",
     "Download logfile" : "Stáhnout soubor logu",
     "More" : "Více",
@@ -194,7 +207,7 @@ OC.L10N.register(
     "What to log" : "Co se má logovat",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Je použita databáze SQLite. Pro větší instalace doporučujeme přejít na robustnější databázi.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Obzvláště při používání klientské aplikace pro synchronizaci s desktopem není SQLite doporučeno.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Pro migraci na jinou databázi lze použít aplikaci pro příkazový řádek: 'occ db:convert-type', nebo nahlédněte do <a target=\"_blank\" href=\"%s\">dokumentace ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Pro migraci na jinou databázi použijte v příkazovém řádku nástroj: 'occ db:convert-type' nebo nahlédněte do <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentace ↗</a>.",
     "How to do backups" : "Jak vytvářet zálohy",
     "Advanced monitoring" : "Pokročilé monitorování",
     "Performance tuning" : "Ladění výkonu",
@@ -210,6 +223,8 @@ OC.L10N.register(
     "Documentation:" : "Dokumentace:",
     "User documentation" : "Dokumentace uživatele",
     "Admin documentation" : "Dokumentace pro administrátory",
+    "Visit website" : "Navštívit webovou stránku",
+    "Report a bug" : "Nahlásit chybu",
     "Show description …" : "Zobrazit popis ...",
     "Hide description …" : "Skrýt popis ...",
     "This app has an update available." : "Pro tuto aplikaci je dostupná aktualizace.",
@@ -256,6 +271,17 @@ OC.L10N.register(
     "Change password" : "Změnit heslo",
     "Language" : "Jazyk",
     "Help translate" : "Pomoci s překladem",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Toto jsou klienti aktuálně přihlášení do této instance ownCloud přes web, počítač, či telefon.",
+    "Browser" : "Prohlížeč",
+    "Most recent activity" : "Nejnovější aktivity",
+    "You've linked these apps." : "Připojili jste tyto aplikace.",
+    "Name" : "Název",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Heslo aplikace je přihlašovací údaj umožňující aplikaci nebo přístroji přístup k %s účtu.",
+    "App name" : "Jméno aplikace",
+    "Create new app password" : "Vytvořit nové heslo aplikace",
+    "Use the credentials below to configure your app or device." : "Použijte níže vypsané přihlašovací údaje k nastavení aplikace nebo přístroje.",
+    "Username" : "Uživatelské jméno",
+    "Done" : "Dokončeno",
     "Get the apps to sync your files" : "Získat aplikace pro synchronizaci vašich souborů",
     "Desktop client" : "Aplikace pro počítač",
     "Android app" : "Aplikace pro Android",
@@ -268,7 +294,6 @@ OC.L10N.register(
     "Show user backend" : "Zobrazit uživatelskou podpůrnou vrstvu",
     "Send email to new user" : "Poslat email novému uživateli",
     "Show email address" : "Emailová adresa",
-    "Username" : "Uživatelské jméno",
     "E-Mail" : "Email",
     "Create" : "Vytvořit",
     "Admin Recovery Password" : "Heslo obnovy správce",
@@ -279,7 +304,6 @@ OC.L10N.register(
     "Admins" : "Administrátoři",
     "Default Quota" : "Výchozí kvóta",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Zvolte prosím kvótu pro úložiště (např. \"512 MB\" nebo \"12 GB\")",
-    "Unlimited" : "Neomezeně",
     "Other" : "Jiný",
     "Full Name" : "Celé jméno",
     "Group Admin for" : "Správce skupiny ",
