@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Segurança & avisos de configuração",
-    "Sharing" : "Compartilhamento",
-    "Server-side encryption" : "Criptografia do lado do servidor",
-    "External Storage" : "Armazenamento Externo",
-    "Cron" : "Cron",
-    "Email server" : "Servidor de Email",
-    "Log" : "Registro",
-    "Tips & tricks" : "Dicas & Truques",
-    "Updates" : "Atualizações",
-    "Couldn't remove app." : "Não foi possível remover aplicativos.",
-    "Language changed" : "Idioma alterado",
-    "Invalid request" : "Pedido inválido",
-    "Authentication error" : "Erro de autenticação",
-    "Admins can't remove themself from the admin group" : "Administradores não pode remover a si mesmos do grupo de administração",
-    "Unable to add user to group %s" : "Não foi possível adicionar usuário ao grupo %s",
-    "Unable to remove user from group %s" : "Não foi possível remover usuário do grupo %s",
-    "Couldn't update app." : "Não foi possível atualizar a app.",
     "Wrong password" : "Senha errada",
     "No user supplied" : "Nenhum usuário fornecido",
+    "Authentication error" : "Erro de autenticação",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Por favor, forneça uma senha de recuperação admin, caso contrário todos os dados do usuário serão perdidos",
     "Wrong admin recovery password. Please check the password and try again." : "Senha de recuperação do administrador errada. Por favor verifique a senha e tente novamente.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Back-end não suporta alteração de senha, mas a chave de criptografia de usuários foi atualizado com sucesso....",
@@ -53,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "E-mail salvo",
     "Your full name has been changed." : "Seu nome completo foi alterado.",
     "Unable to change full name" : "Não é possível alterar o nome completo",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Segurança & avisos de configuração",
+    "Sharing" : "Compartilhamento",
+    "Server-side encryption" : "Criptografia do lado do servidor",
+    "External Storage" : "Armazenamento Externo",
+    "Cron" : "Cron",
+    "Email server" : "Servidor de Email",
+    "Log" : "Registro",
+    "Tips & tricks" : "Dicas & Truques",
+    "Updates" : "Atualizações",
+    "Couldn't remove app." : "Não foi possível remover aplicativos.",
+    "Language changed" : "Idioma alterado",
+    "Invalid request" : "Pedido inválido",
+    "Admins can't remove themself from the admin group" : "Administradores não pode remover a si mesmos do grupo de administração",
+    "Unable to add user to group %s" : "Não foi possível adicionar usuário ao grupo %s",
+    "Unable to remove user from group %s" : "Não foi possível remover usuário do grupo %s",
+    "Couldn't update app." : "Não foi possível atualizar a app.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Você tem certeza que você quer adicionar \"{domain}\" como domínio confiável?",
     "Add trusted domain" : "Adicionar domínio confiável",
     "Migration in progress. Please wait until the migration is finished" : "Migração em progresso. Por favor aguarde até que a migração seja finalizada",
@@ -63,6 +63,7 @@ OC.L10N.register(
     "Experimental" : "Experimental",
     "All" : "Todos",
     "No apps found for your version" : "Nenhum aplicativo encontrados para a sua versão",
+    "The app will be downloaded from the app store" : "O aplicativo será baixado na App Store",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplicativos oficiais são desenvolvidos por e dentro da comunidade ownCloud. Eles oferecem funcionalidade central para ownCloud e estão prontos para uso em produção.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Aplicativos aprovados são desenvolvidos pelos desenvolvedores confiáveis e passaram por uma verificação de segurança superficial. Eles são ativamente mantidos em um repositório de código aberto e seus mantenedores consideram que eles para sejam estáveis para um casual uso normal.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Este aplicativo não foi verificado para as questões de segurança e é novo ou conhecido por ser instável. Instale por seu próprio risco.",
@@ -73,6 +74,9 @@ OC.L10N.register(
     "Disable" : "Desabilitar",
     "Enable" : "Habilitar",
     "Error while enabling app" : "Erro enquanto habilitava o aplicativo",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Erro: este aplicativo não pode ser habilitado porque faz com que o servidor fique instável",
+    "Error: could not disable broken app" : "Erro: Não foi possível desativar o aplicativo quebrado",
+    "Error while disabling broken app" : "Erro ao desativar aplicativo quebrado",
     "Updating...." : "Atualizando...",
     "Error while updating app" : "Erro ao atualizar aplicativo",
     "Updated" : "Atualizado",
@@ -81,7 +85,11 @@ OC.L10N.register(
     "Uninstall" : "Desinstalar",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "O aplicativo foi habilitado, mas precisa ser atualizado. Você será redirecionado para a página de atualização em 5 segundos.",
     "App update" : "Atualização de aplicativo",
-    "No apps found for \"{query}\"" : "Nenhum aplicativo encontrado para \"{query}\"",
+    "No apps found for {query}" : "Nenhum aplicativo encontrados para {query}",
+    "Disconnect" : "Desconectar",
+    "Error while loading browser sessions and device tokens" : "Erro durante carregamento de sessões do navegador e tokens de dispositivos",
+    "Error while creating device token" : "Erro ao criar token de dispositivo",
+    "Error while deleting the token" : "Erro ao excluir o token",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ocorreu um erro. Por favor envie um certificado ASCII-encoded PEM",
     "Valid until {date}" : "Vádido até {date}",
     "Delete" : "Excluir",
@@ -108,7 +116,10 @@ OC.L10N.register(
     "A valid password must be provided" : "Forneça uma senha válida",
     "A valid email must be provided" : "Deve ser informado um e-mail válido",
     "__language_name__" : "__language_name__",
+    "Unlimited" : "Ilimitado",
     "Personal info" : "Informação pessoal",
+    "Sessions" : "Sessões",
+    "App passwords" : "Senhas de aplicativos",
     "Sync clients" : "Clientes de Sincronização",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tudo (questões fatais, erros, avisos, informações, depuração)",
     "Info, warnings, errors and fatal issues" : "Informações, avisos, erros e problemas fatais",
@@ -122,32 +133,34 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parecem esta configurado corretamente para consultar as variáveis de ambiente do sistema. O teste com getenv(\"PATH\") só retorna uma resposta vazia.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor verifique o <a target=\"_blank\" href=\"%s\">documento de instalação ↗</a> para as notas de configuração do PHP e configuração do PHP do seu servidor, especialmente quando usando PHP-FPM.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor verifique a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação de instalação ↗</a> para notas configuração do PHP e a configuração do PHP do seu servidor, especialmente quando se utiliza php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Somente-Leitura foi habilitada. Isso impede que algumas configurações sejam definidas via a interface web. Além disso, o arquivo precisa ter permissão de escrita manual para cada atualização.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP é, aparentemente, a configuração para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por uma cache/acelerador, como Zend OPcache ou eAccelerator.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Seu banco de dados não está sendo executado com \"READ COMMITTED\" nível de isolamento da transação. Isto pode causar problemas quando várias ações são executadas em paralelo.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "O servidor está em execução no Microsoft Windows. Recomendamos Linux para uma excelente experiência para o usuário.",
     "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s abaixo da versão %2$s está instalado, por razões de estabilidade e desempenho recomendamos a atualização para uma nova versão %1$s.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "O módulo PHP 'fileinfo' está faltando. Recomendamos que ative este módulo para obter uma melhor detecção do tipo de mídia (mime-type).",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivos transacional está desativado, isso pode levar a problemas com as condições de corrida. Ativar 'filelocking.enabled' em config.php para evitar esses problemas. Veja  a <a target=\"_blank\" href=\"%s\">documentação ↗</a> para mais informações.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivo transacional está desativado, isso pode levar a problemas com as condições de corrida. Ativar 'filelocking.enabled' em config.php para evitar esses problemas. Veja a  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação ↗</a> para mais informações.",
     "System locale can not be set to a one which supports UTF-8." : "Localidade do sistema não pode ser definido como um que suporta UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Isso significa que pode haver problemas com certos caracteres nos nomes de arquivo.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nós sugerimos a instalação dos pacotes necessários em seu sistema para suportar um dos seguintes locais: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se a sua instalação não estiver instalada na raiz do domínio e usa cron do sistema, pode haver problemas com a geração de URL. Para evitar esses problemas, por favor, defina a opção \"overwrite.cli.url\" em seu arquivo config.php para o caminho webroot de sua instalação (Sugestão: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Não foi possível executar o cron via CLI. Os seguintes erros técnicos têm aparecido:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor, verifique os <a target=\"_blank\" href=\"%s\">guias de instalação ↗</a>, e verificar se há erros ou avisos no <a href=\"#log-section\">log</a>.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor, verifique o <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guias de instalação ↗</a>, e verificar se há erros ou avisos no <a href=\"#log-section\">log</a>.",
     "All checks passed." : "Todas as verificações passaram.",
     "Open documentation" : "Abrir documentação",
     "Allow apps to use the Share API" : "Permitir que aplicativos usem a API de Compartilhamento",
     "Allow users to share via link" : "Permitir que os usuários compartilhem por link",
-    "Enforce password protection" : "Reforce a proteção por senha",
     "Allow public uploads" : "Permitir envio público",
-    "Allow users to send mail notification for shared files" : "Permitir aos usuários enviar notificação de email para arquivos compartilhados",
+    "Enforce password protection" : "Reforce a proteção por senha",
     "Set default expiration date" : "Configurar a data de expiração",
+    "Allow users to send mail notification for shared files" : "Permitir aos usuários enviar notificação de email para arquivos compartilhados",
     "Expire after " : "Expirar depois de",
     "days" : "dias",
     "Enforce expiration date" : "Fazer cumprir a data de expiração",
     "Allow resharing" : "Permitir recompartilhamento",
+    "Allow sharing with groups" : "Permitir o compartilhamento com grupos",
     "Restrict users to only share with users in their groups" : "Restringir os usuários a compartilhar somente com os usuários em seus grupos",
     "Allow users to send mail notification for shared files to other users" : "Permitir aos usuários enviar notificação de email de arquivos compartilhados para outros usuários",
     "Exclude groups from sharing" : "Excluir grupos de compartilhamento",
@@ -194,7 +207,7 @@ OC.L10N.register(
     "What to log" : "O que colocar no log",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite é usada como base de dados. Para instalações maiores recomendamos mudar para um backend de banco de dados diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especialmente quando se utiliza o cliente de desktop para sincronização de arquivos o uso de SQLite é desencorajado.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Para migrar para outro banco de dados usar a ferramenta de linha de comando: 'db occ: converter-type', verifique a <a target=\"_blank\" href=\"%s\">documentação ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Para migrar para outro banco de dados usar a ferramenta de linha de comando: 'occ db:convert-type', ou consulte a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação ↗</a>.",
     "How to do backups" : "Como fazer backups",
     "Advanced monitoring" : "Monitoramento avançado",
     "Performance tuning" : "Aprimorando performance",
@@ -210,6 +223,8 @@ OC.L10N.register(
     "Documentation:" : "Documentação:",
     "User documentation" : "Documentação do usuário",
     "Admin documentation" : "Documentação para Administração",
+    "Visit website" : "Visitar website",
+    "Report a bug" : "Registrar um bug",
     "Show description …" : "Mostrar descrição ...",
     "Hide description …" : "Esconder descrição ...",
     "This app has an update available." : "Este aplicativo tem uma atualização disponível.",
@@ -256,6 +271,17 @@ OC.L10N.register(
     "Change password" : "Alterar senha",
     "Language" : "Idioma",
     "Help translate" : "Ajude a traduzir",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Estes são os clientes web, desktop e clientes móveis atualmente conectado ao seu ownCloud.",
+    "Browser" : "Navegador",
+    "Most recent activity" : "Atividade mais recente",
+    "You've linked these apps." : "Você vinculou esses aplicativos.",
+    "Name" : "Nome",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "A senha do aplicativo é um código de acesso que dá ao aplicativo ou dispositivo permissões para acessar sua conta %s.",
+    "App name" : "Nome do aplicativo",
+    "Create new app password" : "Criar uma nova senha do aplicativo",
+    "Use the credentials below to configure your app or device." : "Use as credenciais abaixo para configurar seu aplicativo ou dispositivo.",
+    "Username" : "Nome de Usuário",
+    "Done" : "Concluída",
     "Get the apps to sync your files" : "Obtenha apps para sincronizar seus arquivos",
     "Desktop client" : "Cliente Desktop",
     "Android app" : "App Android",
@@ -268,7 +294,6 @@ OC.L10N.register(
     "Show user backend" : "Mostrar administrador do usuário",
     "Send email to new user" : "Enviar um email para o novo usuário",
     "Show email address" : "Mostrar o endereço de email",
-    "Username" : "Nome de Usuário",
     "E-Mail" : "E-Mail",
     "Create" : "Criar",
     "Admin Recovery Password" : "Recuperação da Senha do Administrador",
@@ -279,7 +304,6 @@ OC.L10N.register(
     "Admins" : "Administradores",
     "Default Quota" : "Quota Padrão",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor insira cota de armazenamento (ex: \"512\" ou \"12 GB\")",
-    "Unlimited" : "Ilimitado",
     "Other" : "Outro",
     "Full Name" : "Nome Completo",
     "Group Admin for" : "Grupo Admin para",
